#include <linux/init.h>

#include <linux/module.h>
#include <linux/version.h>
#include <linux/kernel.h>
#include <linux/types.h>
#include <linux/pci.h>
#include <linux/init.h>
#include <linux/interrupt.h>
#include <linux/netdevice.h>
#include <linux/sched.h>

#include <linux/delay.h>



#include <asm/io.h>
#include <asm/mach-ralink/rt_mmap.h>
#include "mtk_cAdapter.h"
#include "mtk_baseDefs.h"         // uint32_t
#include "mtk_pecApi.h"            // PEC_* (the API we implement here)
#include "mtk_dmaBuf.h"         // DMABuf_*
#include "mtk_hwDmaAccess.h"      // HWPAL_Resource_*
#include "mtk_cLib.h"               // memcpy
#include "mtk_AdapterInternal.h"
#include "mtk_interrupts.h"
#include "mtk_arm.h"        // driver library API we will use
#include "mtk_descp.h" // for parsing result descriptor

#include <net/mtk_esp.h>
#include "mtk_ipsec.h"
#include <linux/skbuff.h>


extern unsigned int *pCmdRingBase, *pResRingBase; //uncached memory address
extern void mtk_interruptHandler_descriptorDone(void);

#define EIP93_RING_SIZE		((ADAPTER_EIP93_RINGSIZE_BYTES)>>5)
#define EIP93_REG_BASE		(RALINK_CRYPTO_ENGINE_BASE)
#define PE_CD_COUNT			0x00000090
#define	PE_RD_COUNT			0x00000094
#define PE_RING_PNTR		0x00000098
#define PE_CONFIG			0x00000100
#define PE_ENDIAN_CONFIG	0x000001d0
//#define dma_cache_wback_inv(start, size) _dma_cache_wback_inv(start,size)
#define K1_TO_PHY(x)		(((unsigned int)x) & 0x1fffffff)
#define WORDSWAP(a)     	((((a)>>24)&0xff) | (((a)>>8)&0xff00) | (((a)<<8)&0xff0000) | (((a)<<24)&0xff000000))
#define DESCP_SIZE			32
#define EIP93_RING_BUFFER	24

static unsigned int cmdRingIdx, resRingIdx;
static uint32_t *pEip93RegBase = (uint32_t *)EIP93_REG_BASE;

static spinlock_t 			putlock;

#ifdef WORKQUEUE_BH
static DECLARE_WORK(mtk_interrupt_BH_result_wq, mtk_BH_handler_resultGet);
#else
static DECLARE_TASKLET( \
mtk_interrupt_BH_result_tsk, mtk_BH_handler_resultGet, 0);
#endif
static void mtk_interruptHandler_done(void);

#define BUFFER_MEMCPY	1

#if 0
static void skb_dump(struct sk_buff* sk, const char* func,int line) {
        unsigned int i;

        printk("(%d)skb_dump: [%s] with len %d (%08X) headroom=%d tailroom=%d\n",
                line,func,sk->len,sk,
                skb_headroom(sk),skb_tailroom(sk));

        for(i=(unsigned int)sk->head;i<=(unsigned int)sk->data + 400;i++) {
                if((i % 16) == 0)
                        printk("\n");
                if(i==(unsigned int)sk->data) printk("{");
                //if(i==(unsigned int)sk->h.raw) printk("#");
                //if(i==(unsigned int)sk->nh.raw) printk("|");
                //if(i==(unsigned int)sk->mac.raw) printk("*");
                printk("%02x ",*((unsigned char*)i));
                if(i==(unsigned int)(sk->tail)-1) printk("}");
        }
        printk("\n");
}
#else
#define skb_dump //skb_dump
#endif

/************************************************************************
*              P R I V A T E     F U N C T I O N S
*************************************************************************
*/
static void 
mtk_cmdHandler_free(
	eip93DescpHandler_t *cmdHandler
)
{
	saRecord_t *saRecord;
	saState_t *saState;
	dma_addr_t	saPhyAddr, statePhyAddr;
	
	saRecord = (saRecord_t *)cmdHandler->saAddr.addr;
	saPhyAddr = (dma_addr_t)cmdHandler->saAddr.phyAddr;
	saState = (saState_t *)cmdHandler->stateAddr.addr;
	statePhyAddr = (dma_addr_t)cmdHandler->stateAddr.phyAddr;	
	
	dma_free_coherent(NULL, sizeof(saRecord_t), saRecord, saPhyAddr);
	dma_free_coherent(NULL, sizeof(saState_t), saState, statePhyAddr);
	kfree(cmdHandler);
}

/*_______________________________________________________________________
**function name: ipsec_addrsDigestPreCompute_free
**
**description:
*   free those structions that are created for Hash Digest Pre-Compute!
*	Those sturctures won't be used anymore during encryption/decryption!
**parameters:
*   currAdapterPtr -- point to the structure that stores the addresses
*		for those structures for Hash Digest Pre-Compute.
**global:
*   none
**return:
*   none
**call:
*   none
**revision:
*   1.Trey 20120209
**_______________________________________________________________________*/
static void 
mtk_addrsDigestPreCompute_free(
	ipsecEip93Adapter_t *currAdapterPtr
)
{
	unsigned int *ipad, *opad, *hashKeyTank;
	unsigned int *pIDigest, *pODigest;
	unsigned int blkSize;
	saRecord_t *saRecord;
	saState_t *saState, *saState2;
	dma_addr_t	ipadPhyAddr, opadPhyAddr, saPhyAddr, statePhyAddr, statePhyAddr2;
	eip93DescpHandler_t *cmdHandler;
	addrsDigestPreCompute_t *addrsPreCompute;
	
	addrsPreCompute = currAdapterPtr->addrsPreCompute;
	
	if(addrsPreCompute == NULL)
		return;
	
	hashKeyTank = addrsPreCompute->hashKeyTank;
	ipad		= (unsigned int *)addrsPreCompute->ipadHandler.addr;
	ipadPhyAddr = addrsPreCompute->ipadHandler.phyAddr;
	opad		= (unsigned int *)addrsPreCompute->opadHandler.addr;
	opadPhyAddr = addrsPreCompute->opadHandler.phyAddr;
	blkSize 	= addrsPreCompute->blkSize;
	cmdHandler 	= addrsPreCompute->cmdHandler;
	saRecord 	= (saRecord_t *)addrsPreCompute->saHandler.addr;
	saPhyAddr 	= addrsPreCompute->saHandler.phyAddr;
	saState 	= (saState_t *)addrsPreCompute->stateHandler.addr;
	statePhyAddr = addrsPreCompute->stateHandler.phyAddr;
	saState2 	= (saState_t *)addrsPreCompute->stateHandler2.addr;
	statePhyAddr2 = addrsPreCompute->stateHandler2.phyAddr;
	pIDigest 	= addrsPreCompute->pIDigest;
	pODigest 	= addrsPreCompute->pODigest;		

	kfree(pODigest);
	kfree(pIDigest);
	dma_free_coherent(NULL, sizeof(saState_t), saState2, statePhyAddr2);
	dma_free_coherent(NULL, sizeof(saState_t), saState, statePhyAddr);
	dma_free_coherent(NULL, sizeof(saRecord_t), saRecord, saPhyAddr);
	kfree(cmdHandler);		
	dma_free_coherent(NULL, blkSize, opad, opadPhyAddr);		
	dma_free_coherent(NULL, blkSize, ipad, ipadPhyAddr);		
	kfree(hashKeyTank);
	kfree(addrsPreCompute);
	addrsPreCompute->pODigest = NULL;
	addrsPreCompute->pIDigest = NULL;
	currAdapterPtr->addrsPreCompute = NULL;
}

static void 
mtk_hashDigests_get(
	ipsecEip93Adapter_t *currAdapterPtr
)
{
	eip93DescpHandler_t *cmdHandler;
	saRecord_t *saRecord;
	addrsDigestPreCompute_t* addrsPreCompute;
	unsigned int i;
	
	
	cmdHandler = currAdapterPtr->cmdHandler;
	saRecord = (saRecord_t *)cmdHandler->saAddr.addr;
	addrsPreCompute = currAdapterPtr->addrsPreCompute;
	
	for (i = 0; i < (addrsPreCompute->digestWord); i++)
	{
		saRecord->saIDigest[i] = addrsPreCompute->pIDigest[i];
		saRecord->saODigest[i] = addrsPreCompute->pODigest[i];
	}
}

static void 
mtk_hashDigests_set(
	ipsecEip93Adapter_t *currAdapterPtr,
	unsigned int isInOrOut
)
{
//resDescpHandler only has physical addresses, so we have to get saState's virtual address from addrsPreCompute.

	addrsDigestPreCompute_t *addrsPreCompute;
	saState_t *stateHandler;
	unsigned int i, digestWord;
	
	
	addrsPreCompute = (addrsDigestPreCompute_t*) currAdapterPtr->addrsPreCompute;
	digestWord = addrsPreCompute->digestWord;

	if (isInOrOut == 1) //for Inner Digests
	{
		stateHandler = (saState_t *) addrsPreCompute->stateHandler.addr;
		
		for (i = 0; i < digestWord; i++)
		{
			addrsPreCompute->pIDigest[i] = stateHandler->stateIDigest[i];
		}
	}
	else if (isInOrOut == 2) //for Outer Digests
	{
		stateHandler = (saState_t *) addrsPreCompute->stateHandler2.addr;
		
		for (i = 0; i < digestWord; i++)
		{
			addrsPreCompute->pODigest[i] = stateHandler->stateIDigest[i];
		}		
	}
}

static unsigned int 
mtk_eip93UserId_get(
	eip93DescpHandler_t *resHandler
)
{
/* In our case, during hash digest pre-compute, the userId will be
 * currAdapterPtr; but during encryption/decryption, the userId
 * will be skb
 */
	return resHandler->userId;
}

static unsigned int 
mtk_eip93HashFinal_get(
	eip93DescpHandler_t *resHandler
)
{
/* In our case, during hash digest pre-compute, the hashFinal bit 
 * won't be set; but during encryption/decryption, the hashFinal
 * bit will be set
 */
	return resHandler->peCrtlStat.bits.hashFinal;
}

static unsigned int 
mtk_pktLength_get(
	eip93DescpHandler_t *resHandler
)
{
	return resHandler->peLength.bits.length;
}

static unsigned char 
mtk_espNextHeader_get(
	eip93DescpHandler_t *resHandler
)
{
	return resHandler->peCrtlStat.bits.padValue;
}

static void 
mtk_espNextHeader_set(
	eip93DescpHandler_t *cmdHandler, 
	unsigned char protocol	
)
{
	cmdHandler->peCrtlStat.bits.padValue = protocol; //ipsec esp's next-header which is IPPROTO_IPIP for tunnel or ICMP/TCP/UDP for transport mode
}

static int 
mtk_preComputeIn_cmdDescp_set(
	ipsecEip93Adapter_t *currAdapterPtr,
	unsigned int direction
)
{
	addrsDigestPreCompute_t* addrsPreCompute = currAdapterPtr->addrsPreCompute;
	eip93DescpHandler_t *cmdHandler;
	saRecord_t *saRecord;
	saState_t *saState;
	dma_addr_t	saPhyAddr, statePhyAddr;
	int errVal;
	

	cmdHandler = (eip93DescpHandler_t *) kzalloc(sizeof(eip93DescpHandler_t), GFP_KERNEL);
	if (unlikely(cmdHandler == NULL))
	{
		printk("\n\n !!kmalloc for cmdHandler failed!! \n\n");
		return -ENOMEM;
	}
	addrsPreCompute->cmdHandler = cmdHandler;
	
	saRecord = (saRecord_t *) dma_alloc_coherent(NULL, sizeof(saRecord_t), &saPhyAddr, GFP_KERNEL);
	if (unlikely(saRecord == NULL))
	{
		printk("\n\n !!dma_alloc for saRecord failed!! \n\n");
		errVal = -ENOMEM;
		goto free_cmdHandler;
	}
	memset(saRecord, 0, sizeof(saRecord_t));
	addrsPreCompute->saHandler.addr = (unsigned int)saRecord;
	addrsPreCompute->saHandler.phyAddr = saPhyAddr;
	
	saState = (saState_t *) dma_alloc_coherent(NULL, sizeof(saState_t), &statePhyAddr, GFP_KERNEL);
	if (unlikely(saState == NULL))
	{
		printk("\n\n !!dma_alloc for saState failed!! \n\n");
		errVal = -ENOMEM;
		goto free_saRecord;
	}
	memset(saState, 0, sizeof(saState_t));
	addrsPreCompute->stateHandler.addr = (unsigned int)saState;
	addrsPreCompute->stateHandler.phyAddr = statePhyAddr;	
	
	
	saRecord->saCmd0.bits.opCode = 0x3; //basic hash operation
	saRecord->saCmd0.bits.hashSource = 0x3; //no load HASH_SOURCE
	saRecord->saCmd0.bits.saveHash = 0x1;
#if 1
	if (addrsPreCompute->digestWord == 4)
		saRecord->saCmd0.bits.hash = 0x0; //md5
	else if (addrsPreCompute->digestWord == 5)
		saRecord->saCmd0.bits.hash = 0x1; //sha1
	else if (addrsPreCompute->digestWord == 8)
		saRecord->saCmd0.bits.hash = 0x3; //sha256
#endif
	if (direction == HASH_DIGEST_OUT)
	{
		saRecord->saCmd0.bits.direction = 0x0; //outbound
	}
	else if (direction == HASH_DIGEST_IN)
	{
		saRecord->saCmd0.bits.direction = 0x1; //inbound
	}	

	//saRecord->saCmd0.bits.hash = hashAlg;
	
	cmdHandler->peCrtlStat.bits.hostReady = 0x1;
	cmdHandler->srcAddr.phyAddr = addrsPreCompute->ipadHandler.phyAddr;
	cmdHandler->saAddr.phyAddr = saPhyAddr;
	cmdHandler->stateAddr.phyAddr = statePhyAddr;
	cmdHandler->peLength.bits.hostReady = 0x1;
	cmdHandler->peLength.bits.length = (addrsPreCompute->blkSize) & (BIT_20 - 1);

	//save needed info in EIP93's userID, so the needed info can be used by the tasklet which is raised by interrupt.
	cmdHandler->userId = (unsigned int)currAdapterPtr;

	return 1;
	
	
free_saRecord:
	dma_free_coherent(NULL, sizeof(saRecord_t), saRecord, saPhyAddr);
free_cmdHandler:
	kfree(cmdHandler);
	
	return errVal;
}

static int 
mtk_preComputeOut_cmdDescp_set(
	ipsecEip93Adapter_t *currAdapterPtr,
	unsigned int direction
)
{
	addrsDigestPreCompute_t* addrsPreCompute = currAdapterPtr->addrsPreCompute;	
	saState_t *saState2;
	dma_addr_t	statePhyAddr2;
	int errVal;
	eip93DescpHandler_t *cmdHandler = addrsPreCompute->cmdHandler;
	
	
	saState2 = (saState_t *) dma_alloc_coherent(NULL, sizeof(saState_t), &statePhyAddr2, GFP_KERNEL);
	if (unlikely(saState2 == NULL))
	{
		printk("\n\n !!dma_alloc for saState2 failed!! \n\n");
		errVal = -ENOMEM;
		goto free_preComputeIn;
	}
	memset(saState2, 0, sizeof(saState_t));
	addrsPreCompute->stateHandler2.addr = (unsigned int)saState2;
	addrsPreCompute->stateHandler2.phyAddr = statePhyAddr2;	

	
	cmdHandler->srcAddr.phyAddr = addrsPreCompute->opadHandler.phyAddr;
	cmdHandler->stateAddr.phyAddr = statePhyAddr2;

	return 1;	
	
	
free_preComputeIn:
	dma_free_coherent(NULL, sizeof(saState_t), (saState_t *)addrsPreCompute->stateHandler.addr, addrsPreCompute->stateHandler.phyAddr);
	dma_free_coherent(NULL, sizeof(saRecord_t), (saRecord_t *)addrsPreCompute->saHandler.addr, addrsPreCompute->saHandler.phyAddr);
	kfree(addrsPreCompute->cmdHandler);
	
	return errVal;
}

static int 
mtk_cmdHandler_cmdDescp_set(
	ipsecEip93Adapter_t *currAdapterPtr, 
	unsigned int direction,
	unsigned int cipherAlg, 
	unsigned int hashAlg, 
	unsigned int cipherMode, 
	unsigned int enHmac, 
	unsigned int aesKeyLen, 
	unsigned int *cipherKey, 
	unsigned int keyLen, 
	unsigned int spi, 
	unsigned int padCrtlStat
)
{
	eip93DescpHandler_t *cmdHandler;
	saRecord_t *saRecord;
	saState_t *saState;
	dma_addr_t saPhyAddr, statePhyAddr;
	int errVal;
	unsigned int keyWord, i;
	

	cmdHandler = (eip93DescpHandler_t *) kzalloc(sizeof(eip93DescpHandler_t), GFP_KERNEL);
	if (unlikely(cmdHandler == NULL))
	{
		printk("\n\n !!kmalloc for cmdHandler_prepare failed!! \n\n");
		return -ENOMEM;
	}
	
	saRecord = (saRecord_t *) dma_alloc_coherent(NULL, sizeof(saRecord_t), &saPhyAddr, GFP_KERNEL);
	if (unlikely(saRecord == NULL))
	{
		printk("\n\n !!dma_alloc for saRecord_prepare failed!! \n\n");
		errVal = -ENOMEM;
		goto free_cmdHandler;
	}
	memset(saRecord, 0, sizeof(saRecord_t));
	
	saState = (saState_t *) dma_alloc_coherent(NULL, sizeof(saState_t), &statePhyAddr, GFP_KERNEL);
	if (unlikely(saState == NULL))
	{
		printk("\n\n !!dma_alloc for saState_prepare failed!! \n\n");
		errVal = -ENOMEM;
		goto free_saRecord;
	}
	memset(saState, 0, sizeof(saState_t));
	
	
	/* prepare SA */

	if (direction == HASH_DIGEST_OUT)
	{
		currAdapterPtr->isEncryptOrDecrypt = 1; //encrypt
		saRecord->saCmd0.bits.direction = 0x0; //outbound
		saRecord->saCmd0.bits.ivSource = 0x3;//0x3; //load IV from PRNG
		//memset(saState->stateIv, 0, 16);
		//if (cipherAlg == 0x3)
			//saRecord->saCmd1.bits.aesDecKey = 0;
	}
	else if (direction == HASH_DIGEST_IN)
	{
		currAdapterPtr->isEncryptOrDecrypt = 2; //decrypt
		saRecord->saCmd0.bits.direction = 0x1; //inbound
		//if (cipherAlg == 0x3)
			//saRecord->saCmd1.bits.aesDecKey = 1;
	}

	saRecord->saCmd0.bits.opGroup = 0x1;
	saRecord->saCmd0.bits.opCode = 0x0; //esp protocol
	saRecord->saCmd0.bits.cipher = cipherAlg;
	saRecord->saCmd0.bits.hash = hashAlg;
	saRecord->saCmd0.bits.hdrProc = 0x1; //header processing for esp
	if (hashAlg == 0x0F)
		saRecord->saCmd0.bits.digestLength = 0x0; //null auth	
	else	
		saRecord->saCmd0.bits.digestLength = 0x3; //Digest Length for ipsec	
	
	saRecord->saCmd1.bits.cipherMode = cipherMode;
	saRecord->saCmd1.bits.hmac = enHmac;
	if (cipherAlg == 0x3) //aes
		saRecord->saCmd1.bits.arc4KeyLen = aesKeyLen;
		//saRecord->saCmd1.bits.aesKeyLen = aesKeyLen;
	
	//saRecord->saCmd1.bits.seqNumCheck = 1;	
			
	keyWord = keyLen >> 2;
	for (i = 0; i < keyWord; i++)
	{
		//saRecord->saKey[i] = WORDSWAP(cipherKey[i]);
		saRecord->saKey[i] = cipherKey[i];
	}

	saRecord->saSpi = WORDSWAP(spi); //esp spi

	saRecord->saSeqNumMask[0] = 0xFFFFFFFF;
	saRecord->saSeqNumMask[1] = 0x0;
			
	/* prepare command descriptor */
	
	cmdHandler->peCrtlStat.bits.hostReady = 0x1;
	cmdHandler->peCrtlStat.bits.hashFinal = 0x1;
	cmdHandler->peCrtlStat.bits.padCrtlStat = padCrtlStat; //pad boundary

	cmdHandler->saAddr.addr = (unsigned int)saRecord;
	cmdHandler->saAddr.phyAddr = saPhyAddr;
	cmdHandler->stateAddr.addr = (unsigned int)saState;
	cmdHandler->stateAddr.phyAddr = statePhyAddr;
	cmdHandler->arc4Addr.addr = (unsigned int)saState;
	cmdHandler->arc4Addr.phyAddr = statePhyAddr;
	cmdHandler->peLength.bits.hostReady = 0x1;
	cmdHandler->peCrtlStat.bits.peReady = 0;
	
	/* restore cmdHandler for later use */
	currAdapterPtr->cmdHandler = cmdHandler;

	return 1;
	
	
free_saRecord:
	dma_free_coherent(NULL, sizeof(saRecord_t), saRecord, saPhyAddr);
free_cmdHandler:
	kfree(cmdHandler);
	
	return errVal;
}

/*_______________________________________________________________________
**function name: mtk_packet_put
**
**description:
*   put command descriptor into EIP93's Command Descriptor Ring and
*	then kick off EIP93.
**parameters:
*   cmdDescp -- point to the command handler that stores the needed
*		info for the command descriptor.
*	skb -- the packet for encryption/decryption
**global:
*   none
**return:
*   0 -- success.
**call:
*   none
**revision:
*   1.Trey 20120209
**_______________________________________________________________________*/
static int 
mtk_packet_put(
	eip93DescpHandler_t *cmdDescp, 
	struct sk_buff *skb //skb == NULL when in digestPreCompute
)
{
	unsigned int *pCrd = pCmdRingBase;
	ipsecEip93Adapter_t *currAdapterPtr;
	unsigned int addedLen;
	unsigned int *addrCurrAdapter;
	unsigned int flags;
	u32* pData = NULL;
	dma_addr_t pDataPhy;

	
	spin_lock_irqsave(&putlock, flags);
	
	if(cmdRingIdx == EIP93_RING_SIZE)
	{
		cmdRingIdx = 0;
	}
	pCrd += (cmdRingIdx << 3); //cmdRingIdx*8 (a cmdDescp has 8 words!)
	cmdRingIdx++;
		
	//pCrd[0] = cmdDescp->peCrtlStat.word;
	pCrd[3] = cmdDescp->saAddr.phyAddr;
	pCrd[4] = cmdDescp->stateAddr.phyAddr;
	pCrd[5] = cmdDescp->arc4Addr.phyAddr;


	if(likely(skb != NULL))
	{
		addrCurrAdapter = (unsigned int *) &(skb->cb[36]);
		currAdapterPtr = (ipsecEip93Adapter_t *)(*addrCurrAdapter);
		addedLen = currAdapterPtr->addedLen;

		dma_cache_wback_inv((unsigned long)skb->data, (skb->len + addedLen) & (BIT_20 - 1));

#if defined (BUFFER_MEMCPY)
		if (currAdapterPtr->isEncryptOrDecrypt==1)	
		{	
			pData = kmalloc(skb->len + addedLen, GFP_KERNEL);
			*(unsigned int *) &(skb->cb[40]) = pData;
			if(pData==NULL)
			{	
				printk("mtk_packet_put allocate null\n");
				pCrd[1] = K1_TO_PHY(skb->data);
				pCrd[2] = K1_TO_PHY(skb->data);
			}
			else
			{	
				pDataPhy = dma_map_single(NULL, pData, skb->len + addedLen, PCI_DMA_FROMDEVICE);
				//skb_dump(skb,__func__,__LINE__);
				pCrd[1] = K1_TO_PHY(skb->data);
				pCrd[2] = pDataPhy;//K1_TO_PHY(pData);
				
			}
		}
		else
#endif
		{	
			pCrd[1] = K1_TO_PHY(skb->data);
			pCrd[2] = K1_TO_PHY(skb->data);
			//printk("[%d]%s skb->data=%08X\n",__LINE__,__func__,skb->data);
			skb_dump(skb,__func__,__LINE__);
		}
		pCrd[6] = (unsigned int)skb;

		/*When encryption, it is necessary to consider when the packet size is greater than 200, and in tunnel mode (l2tpeth0),
 	          before the packet length longer (+4), otherwise there will be untied.   */

		if((currAdapterPtr->isEncryptOrDecrypt==1) && (skb->len > 200) && !(skb->dev->name == NULL))	
		{
                        if(strcmp(skb->dev->name,"l2tpeth0") == 0)
                        {
                                pCrd[7] = ((skb->len+4) & (BIT_20 - 1)) | (cmdDescp->peLength.word & (~(BIT_22 - 1)));
			}else{
                                pCrd[7] = ((skb->len) & (BIT_20 - 1)) | (cmdDescp->peLength.word & (~(BIT_22 - 1)));
			}
		}else{
                        pCrd[7] = ((skb->len) & (BIT_20 - 1)) | (cmdDescp->peLength.word & (~(BIT_22 - 1)));

		}

	//	if (currAdapterPtr->isEncryptOrDecrypt==1)	
	//		pCrd[7] = ((skb->len) & (BIT_20 - 1)) | (cmdDescp->peLength.word & (~(BIT_22 - 1)));
	//	else
	//		pCrd[7] = ((skb->len) & (BIT_20 - 1)) | (cmdDescp->peLength.word & (~(BIT_22 - 1)));
	}
	else
	{
		pCrd[1] = cmdDescp->srcAddr.phyAddr;
		pCrd[2] = cmdDescp->srcAddr.phyAddr;
		pCrd[6] = cmdDescp->userId;
		pCrd[7] = cmdDescp->peLength.word;
	}
	pCrd[0] = cmdDescp->peCrtlStat.word;
	
	//prevent from inconsistency of HW DMA and SW memory access
	wmb();
	iowrite32(1, pEip93RegBase + (PE_CD_COUNT >> 2)); //PE_CD_COUNT/4	

	spin_unlock_irqrestore(&putlock, flags);
	return 0; //success
}

/*_______________________________________________________________________
**function name: mtk_packet_get
**
**description:
*   get result descriptor from EIP93's Result Descriptor Ring.
**parameters:
*   resDescp -- point to the result handler that stores the needed
*		info for the result descriptor.
**global:
*   none
**return:
*   0  -- EIP93 has no result yet.
*   1  -- EIP93 has results ready.
*   -1 -- the current result is wrong!
**call:
*   none
**revision:
*   1.Trey 20120209
**_______________________________________________________________________*/
static int 
mtk_packet_get(
	eip93DescpHandler_t *resDescp
)
{
	unsigned int *pRrd = pResRingBase;
	unsigned int done1, done2, err_sts, PktCnt, timeCnt = 0;
	struct sk_buff *skb = NULL;
	int retVal;
#if defined (BUFFER_MEMCPY)
	ipsecEip93Adapter_t *currAdapterPtr;
	unsigned int addedLen;
	unsigned int *addrCurrAdapter;
#endif	
	PktCnt = ioread32(pEip93RegBase + (PE_RD_COUNT >> 2)) & (BIT_10 - 1); //PE_RD_COUNT/4

	//don't wait for Crypto Engine in order to speed up!
	if(PktCnt == 0)
	{
		return 0; //no result yet
	}
	
	if(resRingIdx == EIP93_RING_SIZE)
	{
		resRingIdx = 0;
	}	
	pRrd += (resRingIdx << 3); //resRingIdx*8 (a resDescp has 8 words!)

	while (1)
	{
		
		PktCnt = ioread32(pEip93RegBase + (PE_RD_COUNT >> 2)) & (BIT_10 - 1); //PE_RD_COUNT/4

		resDescp->peCrtlStat.word 	= pRrd[0];
		resDescp->userId		 	= pRrd[6];
		resDescp->peLength.word 	= pRrd[7];
		//the others are physical addresses, no need to be copied!
		done1 = resDescp->peCrtlStat.bits.peReady;
		done2 = resDescp->peLength.bits.peReady;
		err_sts = resDescp->peCrtlStat.bits.errStatus;
		resDescp->saAddr.phyAddr = pRrd[3];
		if ((done1 == 1) && (done2 == 1))
		{	
			if(unlikely(err_sts))
			{
				printk("\n\n !Crypto Engine Failed Ring[%d] with Error Code:0x%x! Drop it! PktCnt=%d\n\n", resRingIdx, err_sts, PktCnt);				
				//for encryption/decryption case
				if (resDescp->peCrtlStat.bits.hashFinal == 0x1)
				{
					skb = (struct sk_buff *)resDescp->userId;
					if ((resDescp->userId>>31)&0x1)
					{	
						kfree_skb(skb);
					}
					else
						printk("resDescp->userId = 0x%x\n", resDescp->userId);	
				}
				else {

				}	
					 
				retVal = -1;
				break;
			}
			skb = (struct sk_buff *)resDescp->userId;
#if defined (BUFFER_MEMCPY)
			if((skb!=NULL)&&(resDescp->peCrtlStat.bits.hashFinal == 0x1))
			{
				u8* pData =  0x80000000|pRrd[2];//(unsigned int *)&(skb->cb[40]);
				addrCurrAdapter = (unsigned int *) &(skb->cb[36]);
				currAdapterPtr = (ipsecEip93Adapter_t *)(*addrCurrAdapter);
				if ((currAdapterPtr->isEncryptOrDecrypt==1)&&(pRrd[2]!=pRrd[1]))	
				{	
					memcpy(skb->data, pData, resDescp->peLength.bits.length);
					dma_unmap_single (NULL, pRrd[2], resDescp->peLength.bits.length, PCI_DMA_FROMDEVICE);			
					kfree(pData);
				}

			}
#endif
#if 0
			if((skb!=NULL)&&(resDescp->peCrtlStat.bits.hashFinal == 0x1))
			{	
				{
					int k;
					printk("HWICV[[");
					for (k = 0; k < 12; k++)
						printk("%02X ",skb->data[resDescp->peLength.bits.length-12+k]);
					printk("]]\n");	
				}
			}	
#endif
			if((skb!=NULL)&&(resDescp->peCrtlStat.bits.hashFinal == 0x1))
				skb_dump(skb,__func__,__LINE__);
			retVal = 1;
			break; 
		}
		else
		{
			//if eip93 is done but the result is not ready yet, just reCkeckResult one more time!
			if (timeCnt++ > 10)
			{
				printk("\n !wait eip93's result for too long! Drop it! \n");
				printk("resRingIdx=%d\n",resRingIdx);
				if (resDescp->peCrtlStat.bits.hashFinal == 0x1)
				{
					skb = (struct sk_buff *)resDescp->userId;
					if ((resDescp->userId>>31)&0x1)
						kfree_skb(skb);
					else
						printk("resDescp->userId = 0x%x\n", resDescp->userId);		
				} 
			
				retVal = -1;
				break;
			}
		}
	} //end while(1)
	
	//clear the peCrtlStat of the currrent resRingDescp, in case eip93 can't put the current result in resRingDescp on time!
	pRrd[0] = 0;
	wmb();
	resRingIdx++;
	iowrite32(1, pEip93RegBase + (PE_RD_COUNT >> 2)); //PE_RD_COUNT/4

	return retVal;
}


static bool 
mtk_eip93CmdResCnt_check(
	void
)
{
	return (
		((ioread32(pEip93RegBase + (PE_CD_COUNT >> 2)) & (BIT_10 - 1)) < EIP93_RING_SIZE) &&
		((ioread32(pEip93RegBase + (PE_RD_COUNT >> 2)) & (BIT_10 - 1)) < (EIP93_RING_SIZE - EIP93_RING_BUFFER))
	);
}


static unsigned int 
mtk_espSeqNum_get(
	eip93DescpHandler_t *resHandler
)
{
	saRecord_t *saRecord;
	resHandler->saAddr.addr = (resHandler->saAddr.phyAddr|(0x5<<29));
	saRecord = (saRecord_t *)resHandler->saAddr.addr;

	return saRecord->saSeqNum[0];
}
/************************************************************************
*              P U B L I C     F U N C T I O N S
*************************************************************************
*/
void 
mtk_ipsec_init(
	void
)
{
	printk("== IPSEC Crypto Engine Driver : %s %s ==\n",__DATE__,__TIME__);
	spin_lock_init(&putlock);

	write_c0_config7((read_c0_config7()|(1<<8)));
	
	//iowrite32(0x00400040, pEip93RegBase + (0x10c >> 2));
	//iowrite32(0x00180004, pEip93RegBase + (0x120 >> 2));
		
	ipsec_eip93_adapters_init();
	ipsec_cryptoLock_init(); 

	//function pointer init
	ipsec_packet_put = mtk_packet_put;
	ipsec_packet_get = mtk_packet_get;
	ipsec_eip93CmdResCnt_check = mtk_eip93CmdResCnt_check;
	ipsec_preComputeIn_cmdDescp_set = mtk_preComputeIn_cmdDescp_set;
	ipsec_preComputeOut_cmdDescp_set = mtk_preComputeOut_cmdDescp_set;
	ipsec_cmdHandler_cmdDescp_set = mtk_cmdHandler_cmdDescp_set;
	ipsec_espNextHeader_set = mtk_espNextHeader_set;
	ipsec_espNextHeader_get = mtk_espNextHeader_get;
	ipsec_pktLength_get = mtk_pktLength_get;
	ipsec_eip93HashFinal_get = mtk_eip93HashFinal_get;
	ipsec_eip93UserId_get = mtk_eip93UserId_get;
	ipsec_addrsDigestPreCompute_free = mtk_addrsDigestPreCompute_free;
	ipsec_cmdHandler_free = mtk_cmdHandler_free;
	ipsec_hashDigests_get = mtk_hashDigests_get;
	ipsec_hashDigests_set = mtk_hashDigests_set;
	
	ipsec_espSeqNum_get = mtk_espSeqNum_get;
	
	//eip93 info init
	cmdRingIdx = ioread32(pEip93RegBase + (PE_RING_PNTR >> 2)) & (BIT_10-1); 
	resRingIdx = (ioread32(pEip93RegBase + (PE_RING_PNTR >> 2)) >>16) & (BIT_10-1);
#ifdef WORKQUEUE_BH
	INIT_WORK(&mtk_interrupt_BH_result_wq, mtk_BH_handler_resultGet);
#else
	tasklet_init(&mtk_interrupt_BH_result_tsk, mtk_BH_handler_resultGet , 0);
#endif	
	//eip93 interrupt mode init
	//iowrite32(0x00400040, pEip93RegBase + (0x10c >> 2));
	//iowrite32(0x00180004, pEip93RegBase + (0x120 >> 2));
	
	
  Adapter_Interrupt_ClearAndEnable(IRQ_RDR_THRESH_IRQ);
  Adapter_Interrupt_SetHandler(IRQ_RDR_THRESH_IRQ, mtk_interruptHandler_done);
	
	//EndianSwap Setting for C.L.'s new POF for fix no_word_alignment  (put right b4 kick CryptoEngine)
	iowrite32(0x00000700, pEip93RegBase + (PE_CONFIG >> 2));
	iowrite32(0x00e400e4, pEip93RegBase + (PE_ENDIAN_CONFIG >> 2));

}

void mtk_BH_handler_resultGet(
	unsigned long data
)
{
	ipsec_BH_handler_resultGet();
	Adapter_Interrupt_ClearAndEnable(IRQ_RDR_THRESH_IRQ);
}

static void mtk_interruptHandler_done(void)
{
#ifdef WORKQUEUE_BH
	schedule_work(&mtk_interrupt_BH_result_wq);
#else	
	tasklet_hi_schedule(&mtk_interrupt_BH_result_tsk);
#endif
}
