/*
 * CSID Definition of Group GRE.
 *
 * Moderator: Chad Sheu
 * Group ID: 0x00710000/0x80710000
 */

#ifndef _CSID_GRE_H
#define _CSID_GRE_H

#include "csid_gid.h"

#define _CFG_GRE(x)		(CSID_GIDC_GRE|(x))
#define _STA_GRE(x)		(CSID_GIDS_GRE|(x))

/* Extra Definitions */
#define MAX_GRE_TUNNEL               25
#define MAX_GRE_PEER_SUBNET          25
#define MAX_TNAME_SIZE	 		   	16
#define MAX_WAN_IF_SIZE	 		   	16
#define MAX_CMD_SIZE               256

/* Configuration Items */
#define CSID_C_GRE_TNAME         _CFG_GRE(0x0100)	//T=str,  GRE tunnel name
#define CSID_C_GRE_ENABLE        _CFG_GRE(0x0200)	//T=u8,   enable/disable GRE tunnel
#define CSID_C_GRE_DT            _CFG_GRE(0x0300)	//T=u8,   default tunnel
#define CSID_C_GRE_PEER_IP       _CFG_GRE(0x0400)	//T=ipv4, the IP address of remote router
#define CSID_C_GRE_KEY           _CFG_GRE(0x0500)	//T=u32,  pre-shared key for the tunnel
#define CSID_C_GRE_TTL           _CFG_GRE(0x0600)	//T=u16,  time to live 
#define CSID_C_GRE_PEER_SUBNET   _CFG_GRE(0x0700)	//T=ipv4, the domain of the remote LAN 
#define CSID_C_GRE_PEER_MASK     _CFG_GRE(0x0800)	//T=u8,   the submask of the remote LAN 
#define CSID_C_GRE_LOCAL_IP      _CFG_GRE(0x0900)	//T=ipv4, the IP address of local router
#define CSID_C_GRE_NETBIOS       _CFG_GRE(0x0A00)   //T=u32,  Gre over netbios enable/disable
#define CSID_C_GRE_TOTAL_ENABLE  _CFG_GRE(0x0B00)   //T=u32,  Gre total enable/disable

/* Status Items */ 
#define CSID_S_GRE_ALTERED		 _STA_GRE(0x0001)	//T=u8,  D=0, UI altered
#define CSID_S_GRE_TX_PKTS		 _STA_GRE(0x0100)	//T=u32, D=0, Transmitted Packets
#define CSID_S_GRE_TX_BYTES		 _STA_GRE(0x0200)	//T=u32, D=0, Transmitted Bytes 
#define CSID_S_GRE_RX_PKTS		 _STA_GRE(0x0300)	//T=u32, D=0, Reveived Packets
#define CSID_S_GRE_RX_BYTES		 _STA_GRE(0x0400)	//T=u32, D=0, Reveices Bytes

#endif 

