/*
 * @file Member ID Definition of Group REMOTE.
 *
 * Moderator: Aaron Wu
 * Group ID: 0x00760000/0x80760000
 */

#ifndef _CSID_REMOTE_H
#define _CSID_REMOTE_H

#include "csid_gid.h"

#define _CFG_REMOTE(x)       (CSID_GIDC_REMOTE|(x))
#define _STA_REMOTE(x)       (CSID_GIDS_REMOTE|(x))

/* Extra Definitions */

//Trust AP Items	
#define CSID_S_REMOTE_AP_TRUSTAP_NAME                   _STA_REMOTE(0x0000)  //T=str, trust AP name
#define CSID_S_REMOTE_AP_TRUSTAP_IP                     _STA_REMOTE(0x0080)  //T=ipv4, trust AP IP Address
#define CSID_S_REMOTE_AP_TRUSTAP_MAC                    _STA_REMOTE(0x0100)  //T=mac, trust AP MAC Address
#define CSID_S_REMOTE_AP_TRUSTAP_SSID_AP1               _STA_REMOTE(0x0180)  //T=str, trust AP 2.4G SSID name
#define CSID_S_REMOTE_AP_TRUSTAP_SSID_AP2               _STA_REMOTE(0x0200)  //T=str, trust AP 5G SSID name
#define CSID_S_REMOTE_AP_TRUSTAP_STATUS                 _STA_REMOTE(0x0280)  //T=u8, trust AP status, 0:offline , 1:online, 2:denined
#define CSID_S_REMOTE_AP_TRUSTAP_TRAFFIC                _STA_REMOTE(0x0300)  //T=u32, trust AP traffic statistic
#define CSID_S_REMOTE_AP_TRUSTAP_VID_LOCATION           _STA_REMOTE(0x0380)  //T=u16, trust AP VID location
#define CSID_S_REMOTE_AP_TRUSTAP_CHANNEL_AP1            _STA_REMOTE(0x0400)  //T=u16, trust AP 2.4G channel
#define CSID_S_REMOTE_AP_TRUSTAP_CHANNEL_AP2            _STA_REMOTE(0x0480)  //T=u16, trust AP 5G channel
#define CSID_S_REMOTE_AP_TRUSTAP_ASSOICATED_AP1         _STA_REMOTE(0x0500)  //T=u32, trust AP 2.4G Assoicated station number
#define CSID_S_REMOTE_AP_TRUSTAP_ASSOICATED_AP2         _STA_REMOTE(0x0580)  //T=u32, trust AP 5G Assoicated station number
#define CSID_S_REMOTE_AP_TRUSTAP_CPU_USED               _STA_REMOTE(0x0600)  //T=str, trust AP CPU Used
#define CSID_S_REMOTE_AP_TRUSTAP_MEMORY_USED            _STA_REMOTE(0x0680)  //T=u32, trust AP Memory Used
//Known AP Items
#define CSID_S_REMOTE_AP_KNOWNAP_IP                	    _STA_REMOTE(0x0700)  //T=ipv4, known AP IP Address
#define CSID_S_REMOTE_AP_KNOWNAP_MAC                	_STA_REMOTE(0x0780)  //T=mac, known AP MAC Address
#define CSID_S_REMOTE_AP_KNOWNAP_SSID_AP1               _STA_REMOTE(0x0800)  //T=str, known AP 2.4G SSID name
#define CSID_S_REMOTE_AP_KNOWNAP_SSID_AP2               _STA_REMOTE(0x0880)  //T=str, known AP 5G SSID name
#define CSID_S_REMOTE_AP_KNOWNAP_STATUS               	_STA_REMOTE(0x0900)  //T=u8, known AP status, 0:offline , 1:online, 2:denined
#define CSID_S_REMOTE_AP_KNOWNAP_VID_LOCATION           _STA_REMOTE(0x0980)  //T=u16, known AP VID location
#define CSID_S_REMOTE_AP_KNOWNAP_CHANNEL_AP1            _STA_REMOTE(0x0a00)  //T=u16, known AP 2.4G channel
#define CSID_S_REMOTE_AP_KNOWNAP_CHANNEL_AP2            _STA_REMOTE(0x0a80)  //T=u16, known AP 5G channel
//Rouge AP Items
#define CSID_S_REMOTE_AP_ROUGEAP_MAC                	_STA_REMOTE(0x0b00)  //T=mac, rouge AP MAC Address
#define CSID_S_REMOTE_AP_ROUGEAP_SSID_AP1              	_STA_REMOTE(0x0b80)  //T=str, rouge AP 2.4G SSID name
#define CSID_S_REMOTE_AP_ROUGEAP_SSID_AP2              	_STA_REMOTE(0x0c00)  //T=str, rouge AP 5G SSID name
#define CSID_S_REMOTE_AP_ROUGEAP_STATUS              	_STA_REMOTE(0x0c80)  //T=u8, rouge AP status, 0:offline , 1:online, 2:denined
#define CSID_S_REMOTE_AP_ROUGEAP_VID_LOCATION           _STA_REMOTE(0x0d00)  //T=u16, rouge AP VID location
#define CSID_S_REMOTE_AP_ROUGEAP_CHANNEL_AP1            _STA_REMOTE(0x0d80)  //T=u16, known AP 2.4G channel
#define CSID_S_REMOTE_AP_ROUGEAP_CHANNEL_AP2            _STA_REMOTE(0x0e00)  //T=u16, known AP 5G channel

/* Wireless 2.4G */
#define CSID_S_REMOTE_AP_WLANENABLE                	    _STA_REMOTE(0x0e80)  //T=u8, AP Wireless Main function, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_WIRELESS_MODE             	    _STA_REMOTE(0x0f00)  //T=u8, AP wireless mode
#define CSID_S_REMOTE_AP_GREEN_AP                  	    _STA_REMOTE(0x0f80)  //T=u8, AP Green AP, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_LAZY_MODE                 	    _STA_REMOTE(0x1000)  //T=u8, AP Lazy Mode, 0:Disable, 1:Enable
//SSID Enable
#define CSID_S_REMOTE_AP_VAP1_APID_ENABLE          	    _STA_REMOTE(0x1080)  //T=u8, AP VAP1 SSID function, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP2_APID_ENABLE          	    _STA_REMOTE(0x1100)  //T=u8, AP VAP2 SSID function, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP3_APID_ENABLE               _STA_REMOTE(0x1180)  //T=u8, AP VAP3 SSID function, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP4_APID_ENABLE          	    _STA_REMOTE(0x1200)  //T=u8, AP VAP4 SSID function, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP5_APID_ENABLE          	    _STA_REMOTE(0x1280)  //T=u8, AP VAP5 SSID function, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP6_APID_ENABLE          	    _STA_REMOTE(0x1300)  //T=u8, AP VAP6 SSID function, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP7_APID_ENABLE          	    _STA_REMOTE(0x1380)  //T=u8, AP VAP7 SSID function, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP8_APID_ENABLE          	    _STA_REMOTE(0x1400)  //T=u8, AP VAP8 SSID function, 0:Disable, 1:Enable
//Schedule
#define CSID_S_REMOTE_AP_VAP1_USE_RULE_NO          	    _STA_REMOTE(0x1480)  //T=u16, AP VAP1 schedule number
#define CSID_S_REMOTE_AP_VAP2_USE_RULE_NO          	    _STA_REMOTE(0x1500)  //T=u16, AP VAP2 schedule number
#define CSID_S_REMOTE_AP_VAP3_USE_RULE_NO          	    _STA_REMOTE(0x1580)  //T=u16, AP VAP3 schedule number
#define CSID_S_REMOTE_AP_VAP4_USE_RULE_NO          	    _STA_REMOTE(0x1600)  //T=u16, AP VAP4 schedule number
#define CSID_S_REMOTE_AP_VAP5_USE_RULE_NO          	    _STA_REMOTE(0x1680)  //T=u16, AP VAP5 schedule number
#define CSID_S_REMOTE_AP_VAP6_USE_RULE_NO          	    _STA_REMOTE(0x1700)  //T=u16, AP VAP6 schedule number
#define CSID_S_REMOTE_AP_VAP7_USE_RULE_NO          	    _STA_REMOTE(0x1780)  //T=u16, AP VAP7 schedule number
#define CSID_S_REMOTE_AP_VAP8_USE_RULE_NO          	    _STA_REMOTE(0x1800)  //T=u16, AP VAP8 schedule number
//SSID
#define CSID_S_REMOTE_AP_VAP1_SSID             		    _STA_REMOTE(0x1880)  //T=str, AP VAP1 SSID Name
#define CSID_S_REMOTE_AP_VAP2_SSID             		    _STA_REMOTE(0x1900)  //T=str, AP VAP2 SSID Name
#define CSID_S_REMOTE_AP_VAP3_SSID             		    _STA_REMOTE(0x1980)  //T=str, AP VAP3 SSID Name
#define CSID_S_REMOTE_AP_VAP4_SSID             		    _STA_REMOTE(0x1a00)  //T=str, AP VAP4 SSID Name
#define CSID_S_REMOTE_AP_VAP5_SSID             		    _STA_REMOTE(0x1a80)  //T=str, AP VAP5 SSID Name
#define CSID_S_REMOTE_AP_VAP6_SSID            		    _STA_REMOTE(0x1b00)  //T=str, AP VAP6 SSID Name
#define CSID_S_REMOTE_AP_VAP7_SSID             		    _STA_REMOTE(0x1b80)  //T=str, AP VAP7 SSID Name
#define CSID_S_REMOTE_AP_VAP8_SSID             		    _STA_REMOTE(0x1c00)  //T=str, AP VAP8 SSID Name
//SSID Broadcast
#define CSID_S_REMOTE_AP_VAP1_HIDESSID                  _STA_REMOTE(0x1c80)  //T=u8, AP VAP1 SSID Broadcsat, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP2_HIDESSID                  _STA_REMOTE(0x1d00)  //T=u8, AP VAP2 SSID Broadcsat, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP3_HIDESSID                  _STA_REMOTE(0x1d80)  //T=u8, AP VAP3 SSID Broadcsat, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP4_HIDESSID                  _STA_REMOTE(0x1e00)  //T=u8, AP VAP4 SSID Broadcsat, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP5_HIDESSID                  _STA_REMOTE(0x1e80)  //T=u8, AP VAP5 SSID Broadcsat, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP6_HIDESSID                  _STA_REMOTE(0x1f00)  //T=u8, AP VAP6 SSID Broadcsat, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP7_HIDESSID                  _STA_REMOTE(0x1f80)  //T=u8, AP VAP7 SSID Broadcsat, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP8_HIDESSID                  _STA_REMOTE(0x2000)  //T=u8, AP VAP8 SSID Broadcsat, 0:Disable, 1:Enable
//WLAN Pratition
#define CSID_S_REMOTE_AP_VAP1_NOFORWARDING              _STA_REMOTE(0x2080)	//T=u8, AP VAP1 WLAN Partitation, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP2_NOFORWARDING              _STA_REMOTE(0x2100)	//T=u8, AP VAP2 WLAN Partitation, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP3_NOFORWARDING              _STA_REMOTE(0x2180)	//T=u8, AP VAP3 WLAN Partitation, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP4_NOFORWARDING              _STA_REMOTE(0x2200)	//T=u8, AP VAP4 WLAN Partitation, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP5_NOFORWARDING              _STA_REMOTE(0x2280)	//T=u8, AP VAP5 WLAN Partitation, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP6_NOFORWARDING              _STA_REMOTE(0x2300)	//T=u8, AP VAP6 WLAN Partitation, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP7_NOFORWARDING              _STA_REMOTE(0x2380)	//T=u8, AP VAP7 WLAN Partitation, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP8_NOFORWARDING              _STA_REMOTE(0x2400)	//T=u8, AP VAP8 WLAN Partitation, 0:Disable, 1:Enable
//CHANNEL
#define CSID_S_REMOTE_AP_VAP1_CHANNEL                   _STA_REMOTE(0x2480)	//T=u8, AP VAP1 Channel
#define CSID_S_REMOTE_AP_VAP2_CHANNEL                   _STA_REMOTE(0x2500)	//T=u8, AP VAP2 Channel
#define CSID_S_REMOTE_AP_VAP3_CHANNEL                   _STA_REMOTE(0x2580)	//T=u8, AP VAP3 Channel
#define CSID_S_REMOTE_AP_VAP4_CHANNEL                   _STA_REMOTE(0x2600)	//T=u8, AP VAP4 Channel
#define CSID_S_REMOTE_AP_VAP5_CHANNEL                   _STA_REMOTE(0x2680)	//T=u8, AP VAP5 Channel
#define CSID_S_REMOTE_AP_VAP6_CHANNEL                   _STA_REMOTE(0x2700)	//T=u8, AP VAP6 Channel
#define CSID_S_REMOTE_AP_VAP7_CHANNEL                   _STA_REMOTE(0x2780)	//T=u8, AP VAP7 Channel
#define CSID_S_REMOTE_AP_VAP8_CHANNEL                   _STA_REMOTE(0x2800)	//T=u8, AP VAP8 Channel
//WirelessMode
#define CSID_S_REMOTE_AP_VAP1_WIRLESSMODE               _STA_REMOTE(0x2880)	//T=u8, AP VAP1 Wireless Mode
#define CSID_S_REMOTE_AP_VAP2_WIRLESSMODE               _STA_REMOTE(0x2900)	//T=u8, AP VAP2 Wireless Mode
#define CSID_S_REMOTE_AP_VAP3_WIRLESSMODE               _STA_REMOTE(0x2980)	//T=u8, AP VAP3 Wireless Mode
#define CSID_S_REMOTE_AP_VAP4_WIRLESSMODE               _STA_REMOTE(0x2a00)	//T=u8, AP VAP4 Wireless Mode
#define CSID_S_REMOTE_AP_VAP5_WIRLESSMODE               _STA_REMOTE(0x2a80)	//T=u8, AP VAP5 Wireless Mode
#define CSID_S_REMOTE_AP_VAP6_WIRLESSMODE               _STA_REMOTE(0x2b00)	//T=u8, AP VAP6 Wireless Mode
#define CSID_S_REMOTE_AP_VAP7_WIRLESSMODE               _STA_REMOTE(0x2b80)	//T=u8, AP VAP7 Wireless Mode
#define CSID_S_REMOTE_AP_VAP8_WIRLESSMODE               _STA_REMOTE(0x2c00)	//T=u8, AP VAP8 Wireless Mode
//AuthMode
#define CSID_S_REMOTE_AP_VAP1_AUTHMODE                  _STA_REMOTE(0x2c80)	//T=u8, AP VAP1 Authenication Type
#define CSID_S_REMOTE_AP_VAP2_AUTHMODE                  _STA_REMOTE(0x2d00)	//T=u8, AP VAP2 Authenication Type
#define CSID_S_REMOTE_AP_VAP3_AUTHMODE                  _STA_REMOTE(0x2d80)	//T=u8, AP VAP3 Authenication Type
#define CSID_S_REMOTE_AP_VAP4_AUTHMODE                  _STA_REMOTE(0x2e00)	//T=u8, AP VAP4 Authenication Type
#define CSID_S_REMOTE_AP_VAP5_AUTHMODE                  _STA_REMOTE(0x2e80)	//T=u8, AP VAP5 Authenication Type
#define CSID_S_REMOTE_AP_VAP6_AUTHMODE                  _STA_REMOTE(0x2f00)	//T=u8, AP VAP6 Authenication Type
#define CSID_S_REMOTE_AP_VAP7_AUTHMODE                  _STA_REMOTE(0x2f80)	//T=u8, AP VAP7 Authenication Type
#define CSID_S_REMOTE_AP_VAP8_AUTHMODE                  _STA_REMOTE(0x3000)	//T=u8, AP VAP8 Authenication Type
//IEEE 8021x       
#define CSID_S_REMOTE_AP_VAP1_IEEE8021X                 _STA_REMOTE(0x3080)	//T=u8, AP VAP1 8021X, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP2_IEEE8021X                 _STA_REMOTE(0x3100)	//T=u8, AP VAP2 8021X, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP3_IEEE8021X                 _STA_REMOTE(0x3180)	//T=u8, AP VAP3 8021X, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP4_IEEE8021X                 _STA_REMOTE(0x3200)	//T=u8, AP VAP4 8021X, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP5_IEEE8021X                 _STA_REMOTE(0x3280)	//T=u8, AP VAP5 8021X, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP6_IEEE8021X                 _STA_REMOTE(0x3300)	//T=u8, AP VAP6 8021X, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP7_IEEE8021X                 _STA_REMOTE(0x3380)	//T=u8, AP VAP7 8021X, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP8_IEEE8021X                 _STA_REMOTE(0x3400)	//T=u8, AP VAP8 8021X, 0:Disable, 1:Enable
//Encryption
#define CSID_S_REMOTE_AP_VAP1_ENCRYPTYPE                _STA_REMOTE(0x3480)	//T=u8, AP VAP1 Encryption Type
#define CSID_S_REMOTE_AP_VAP2_ENCRYPTYPE                _STA_REMOTE(0x3500)	//T=u8, AP VAP2 Encryption Type
#define CSID_S_REMOTE_AP_VAP3_ENCRYPTYPE                _STA_REMOTE(0x3580)	//T=u8, AP VAP3 Encryption Type
#define CSID_S_REMOTE_AP_VAP4_ENCRYPTYPE                _STA_REMOTE(0x3600)	//T=u8, AP VAP4 Encryption Type
#define CSID_S_REMOTE_AP_VAP5_ENCRYPTYPE                _STA_REMOTE(0x3680)	//T=u8, AP VAP5 Encryption Type
#define CSID_S_REMOTE_AP_VAP6_ENCRYPTYPE                _STA_REMOTE(0x3700)	//T=u8, AP VAP6 Encryption Type
#define CSID_S_REMOTE_AP_VAP7_ENCRYPTYPE                _STA_REMOTE(0x3780)	//T=u8, AP VAP7 Encryption Type
#define CSID_S_REMOTE_AP_VAP8_ENCRYPTYPE                _STA_REMOTE(0x3800)	//T=u8, AP VAP8 Encryption Type
//WebKey Index       
#define CSID_S_REMOTE_AP_VAP1_DEFKEYID                  _STA_REMOTE(0x3880)	//T=u8, D=1, AP VAP1 Default WEP Key ID
#define CSID_S_REMOTE_AP_VAP2_DEFKEYID                  _STA_REMOTE(0x3900)	//T=u8, D=1, AP VAP2 Default WEP Key ID
#define CSID_S_REMOTE_AP_VAP3_DEFKEYID                  _STA_REMOTE(0x3980)	//T=u8, D=1, AP VAP3 Default WEP Key ID
#define CSID_S_REMOTE_AP_VAP4_DEFKEYID                  _STA_REMOTE(0x3a00)	//T=u8, D=1, AP VAP4 Default WEP Key ID
#define CSID_S_REMOTE_AP_VAP5_DEFKEYID                  _STA_REMOTE(0x3a80)	//T=u8, D=1, AP VAP5 Default WEP Key ID
#define CSID_S_REMOTE_AP_VAP6_DEFKEYID                  _STA_REMOTE(0x3b00)	//T=u8, D=1, AP VAP6 Default WEP Key ID
#define CSID_S_REMOTE_AP_VAP7_DEFKEYID                  _STA_REMOTE(0x3b80)	//T=u8, D=1, AP VAP7 Default WEP Key ID
#define CSID_S_REMOTE_AP_VAP8_DEFKEYID                  _STA_REMOTE(0x3c00)	//T=u8, D=1, AP VAP8 Default WEP Key ID
//WebKey key1 Type
#define CSID_S_REMOTE_AP_VAP1_KEY0TYPE                  _STA_REMOTE(0x3c80)	//T=u8, D=0, AP VAP1 WEP Key0 Type
#define CSID_S_REMOTE_AP_VAP2_KEY0TYPE                  _STA_REMOTE(0x3d00)	//T=u8, D=0, AP VAP2 WEP Key0 Type
#define CSID_S_REMOTE_AP_VAP3_KEY0TYPE                  _STA_REMOTE(0x3d80)	//T=u8, D=0, AP VAP3 WEP Key0 Type
#define CSID_S_REMOTE_AP_VAP4_KEY0TYPE                  _STA_REMOTE(0x3e00)	//T=u8, D=0, AP VAP4 WEP Key0 Type
#define CSID_S_REMOTE_AP_VAP5_KEY0TYPE                  _STA_REMOTE(0x3e80)	//T=u8, D=0, AP VAP5 WEP Key0 Type
#define CSID_S_REMOTE_AP_VAP6_KEY0TYPE                  _STA_REMOTE(0x3f00)	//T=u8, D=0, AP VAP6 WEP Key0 Type
#define CSID_S_REMOTE_AP_VAP7_KEY0TYPE                  _STA_REMOTE(0x3f80)	//T=u8, D=0, AP VAP7 WEP Key0 Type
#define CSID_S_REMOTE_AP_VAP8_KEY0TYPE                  _STA_REMOTE(0x4000)	//T=u8, D=0, AP VAP8 WEP Key0 Type
//Webkey 1
#define CSID_S_REMOTE_AP_VAP1_KEY0                      _STA_REMOTE(0x4080)	//T=str, D="1234567890", AP VAP1 WEP Key0 Value
#define CSID_S_REMOTE_AP_VAP2_KEY0                      _STA_REMOTE(0x4100)	//T=str, D="1234567890", AP VAP2 WEP Key0 Value
#define CSID_S_REMOTE_AP_VAP3_KEY0                      _STA_REMOTE(0x4180)	//T=str, D="1234567890", AP VAP3 WEP Key0 Value
#define CSID_S_REMOTE_AP_VAP4_KEY0                      _STA_REMOTE(0x4200)	//T=str, D="1234567890", AP VAP4 WEP Key0 Value
#define CSID_S_REMOTE_AP_VAP5_KEY0                      _STA_REMOTE(0x4280)	//T=str, D="1234567890", AP VAP5 WEP Key0 Value
#define CSID_S_REMOTE_AP_VAP6_KEY0                      _STA_REMOTE(0x4300)	//T=str, D="1234567890", AP VAP6 WEP Key0 Value
#define CSID_S_REMOTE_AP_VAP7_KEY0                      _STA_REMOTE(0x4380)	//T=str, D="1234567890", AP VAP7 WEP Key0 Value
#define CSID_S_REMOTE_AP_VAP8_KEY0                      _STA_REMOTE(0x4400)	//T=str, D="1234567890", AP VAP8 WEP Key0 Value
//WebKey key2 Type
#define CSID_S_REMOTE_AP_VAP1_KEY1TYPE                  _STA_REMOTE(0x4480)	//T=u8, D=0, AP VAP1 WEP Key1 Type
#define CSID_S_REMOTE_AP_VAP2_KEY1TYPE                  _STA_REMOTE(0x4500)	//T=u8, D=0, AP VAP2 WEP Key1 Type
#define CSID_S_REMOTE_AP_VAP3_KEY1TYPE                  _STA_REMOTE(0x4580)	//T=u8, D=0, AP VAP3 WEP Key1 Type
#define CSID_S_REMOTE_AP_VAP4_KEY1TYPE                  _STA_REMOTE(0x4600)	//T=u8, D=0, AP VAP4 WEP Key1 Type
#define CSID_S_REMOTE_AP_VAP5_KEY1TYPE                  _STA_REMOTE(0x4680)	//T=u8, D=0, AP VAP5 WEP Key1 Type
#define CSID_S_REMOTE_AP_VAP6_KEY1TYPE                  _STA_REMOTE(0x4700)	//T=u8, D=0, AP VAP6 WEP Key1 Type
#define CSID_S_REMOTE_AP_VAP7_KEY1TYPE                  _STA_REMOTE(0x4780)	//T=u8, D=0, AP VAP7 WEP Key1 Type
#define CSID_S_REMOTE_AP_VAP8_KEY1TYPE                  _STA_REMOTE(0x4800)	//T=u8, D=0, AP VAP8 WEP Key1 Type
//Webkey 2
#define CSID_S_REMOTE_AP_VAP1_KEY1                      _STA_REMOTE(0x4880)	//T=str, D="1234567890", AP VAP1 WEP Key1 Value
#define CSID_S_REMOTE_AP_VAP2_KEY1                      _STA_REMOTE(0x4900)	//T=str, D="1234567890", AP VAP2 WEP Key1 Value
#define CSID_S_REMOTE_AP_VAP3_KEY1                      _STA_REMOTE(0x4980)	//T=str, D="1234567890", AP VAP3 WEP Key1 Value
#define CSID_S_REMOTE_AP_VAP4_KEY1                      _STA_REMOTE(0x4a00)	//T=str, D="1234567890", AP VAP4 WEP Key1 Value
#define CSID_S_REMOTE_AP_VAP5_KEY1                      _STA_REMOTE(0x4a80)	//T=str, D="1234567890", AP VAP5 WEP Key1 Value
#define CSID_S_REMOTE_AP_VAP6_KEY1                      _STA_REMOTE(0x4b00)	//T=str, D="1234567890", AP VAP6 WEP Key1 Value
#define CSID_S_REMOTE_AP_VAP7_KEY1                      _STA_REMOTE(0x4b80)	//T=str, D="1234567890", AP VAP7 WEP Key1 Value
#define CSID_S_REMOTE_AP_VAP8_KEY1                      _STA_REMOTE(0x4c00)	//T=str, D="1234567890", AP VAP8 WEP Key1 Value
//WebKey key3 Type
#define CSID_S_REMOTE_AP_VAP1_KEY2TYPE                  _STA_REMOTE(0x4c80)	//T=u8, D=0, AP VAP1 WEP Key2 Type
#define CSID_S_REMOTE_AP_VAP2_KEY2TYPE                  _STA_REMOTE(0x4d00)	//T=u8, D=0, AP VAP2 WEP Key2 Type
#define CSID_S_REMOTE_AP_VAP3_KEY2TYPE                  _STA_REMOTE(0x4d80)	//T=u8, D=0, AP VAP3 WEP Key2 Type
#define CSID_S_REMOTE_AP_VAP4_KEY2TYPE                  _STA_REMOTE(0x4e00)	//T=u8, D=0, AP VAP4 WEP Key2 Type
#define CSID_S_REMOTE_AP_VAP5_KEY2TYPE                  _STA_REMOTE(0x4e80)	//T=u8, D=0, AP VAP5 WEP Key2 Type
#define CSID_S_REMOTE_AP_VAP6_KEY2TYPE                  _STA_REMOTE(0x4f00)	//T=u8, D=0, AP VAP6 WEP Key2 Type
#define CSID_S_REMOTE_AP_VAP7_KEY2TYPE                  _STA_REMOTE(0x4f80)	//T=u8, D=0, AP VAP7 WEP Key2 Type
#define CSID_S_REMOTE_AP_VAP8_KEY2TYPE                  _STA_REMOTE(0x5000)	//T=u8, D=0, AP VAP8 WEP Key2 Type
//Webkey 3
#define CSID_S_REMOTE_AP_VAP1_KEY2                      _STA_REMOTE(0x5080)	//T=str, D="1234567890", AP VAP1 WEP Key2 Value
#define CSID_S_REMOTE_AP_VAP2_KEY2                      _STA_REMOTE(0x5100)	//T=str, D="1234567890", AP VAP2 WEP Key2 Value
#define CSID_S_REMOTE_AP_VAP3_KEY2                      _STA_REMOTE(0x5180)	//T=str, D="1234567890", AP VAP3 WEP Key2 Value
#define CSID_S_REMOTE_AP_VAP4_KEY2                      _STA_REMOTE(0x5200)	//T=str, D="1234567890", AP VAP4 WEP Key2 Value
#define CSID_S_REMOTE_AP_VAP5_KEY2                      _STA_REMOTE(0x5280)	//T=str, D="1234567890", AP VAP5 WEP Key2 Value
#define CSID_S_REMOTE_AP_VAP6_KEY2                      _STA_REMOTE(0x5300)	//T=str, D="1234567890", AP VAP6 WEP Key2 Value
#define CSID_S_REMOTE_AP_VAP7_KEY2                      _STA_REMOTE(0x5380)	//T=str, D="1234567890", AP VAP7 WEP Key2 Value
#define CSID_S_REMOTE_AP_VAP8_KEY2                      _STA_REMOTE(0x5400)	//T=str, D="1234567890", AP VAP8 WEP Key2 Value
//WebKey key4 Type
#define CSID_S_REMOTE_AP_VAP1_KEY3TYPE             	    _STA_REMOTE(0x5480)	//T=u8, D=0, AP VAP1 WEP Key3 Type
#define CSID_S_REMOTE_AP_VAP2_KEY3TYPE             	    _STA_REMOTE(0x5500)	//T=u8, D=0, AP VAP2 WEP Key3 Type
#define CSID_S_REMOTE_AP_VAP3_KEY3TYPE             	    _STA_REMOTE(0x5580)	//T=u8, D=0, AP VAP3 WEP Key3 Type	
#define CSID_S_REMOTE_AP_VAP4_KEY3TYPE             	    _STA_REMOTE(0x5600)	//T=u8, D=0, AP VAP4 WEP Key3 Type
#define CSID_S_REMOTE_AP_VAP5_KEY3TYPE             	    _STA_REMOTE(0x5680)	//T=u8, D=0, AP VAP5 WEP Key3 Type
#define CSID_S_REMOTE_AP_VAP6_KEY3TYPE             	    _STA_REMOTE(0x5700)	//T=u8, D=0, AP VAP6 WEP Key3 Type
#define CSID_S_REMOTE_AP_VAP7_KEY3TYPE             	    _STA_REMOTE(0x5780)	//T=u8, D=0, AP VAP7 WEP Key3 Type
#define CSID_S_REMOTE_AP_VAP8_KEY3TYPE             	    _STA_REMOTE(0x5800)	//T=u8, D=0, AP VAP8 WEP Key3 Type
//Webkey 4
#define CSID_S_REMOTE_AP_VAP1_KEY3                 	    _STA_REMOTE(0x5880)	//T=str, D="1234567890", AP VAP1 WEP Key3 Value
#define CSID_S_REMOTE_AP_VAP2_KEY3                 	    _STA_REMOTE(0x5900)	//T=str, D="1234567890", AP VAP2 WEP Key3 Value
#define CSID_S_REMOTE_AP_VAP3_KEY3                	    _STA_REMOTE(0x5980)	//T=str, D="1234567890", AP VAP3 WEP Key3 Value
#define CSID_S_REMOTE_AP_VAP4_KEY3                 	    _STA_REMOTE(0x5a00)	//T=str, D="1234567890", AP VAP4 WEP Key3 Value
#define CSID_S_REMOTE_AP_VAP5_KEY3                 	    _STA_REMOTE(0x5a80)	//T=str, D="1234567890", AP VAP5 WEP Key3 Value
#define CSID_S_REMOTE_AP_VAP6_KEY3                 	    _STA_REMOTE(0x5b00)	//T=str, D="1234567890", AP VAP6 WEP Key3 Value
#define CSID_S_REMOTE_AP_VAP7_KEY3                 	    _STA_REMOTE(0x5b80)	//T=str, D="1234567890", AP VAP7 WEP Key3 Value
#define CSID_S_REMOTE_AP_VAP8_KEY3                 	    _STA_REMOTE(0x5c00)	//T=str, D="1234567890", AP VAP8 WEP Key3 Value
//Preshare Key
#define CSID_S_REMOTE_AP_VAP1_WPAPSK               	    _STA_REMOTE(0x5c80)	//T=str, D="1234567890", AP VAP1 WPA PSK Value 
#define CSID_S_REMOTE_AP_VAP2_WPAPSK               	    _STA_REMOTE(0x5d00)	//T=str, D="1234567890", AP VAP2 WPA PSK Value 
#define CSID_S_REMOTE_AP_VAP3_WPAPSK               	    _STA_REMOTE(0x5d80)	//T=str, D="1234567890", AP VAP3 WPA PSK Value 
#define CSID_S_REMOTE_AP_VAP4_WPAPSK               	    _STA_REMOTE(0x5e00)	//T=str, D="1234567890", AP VAP4 WPA PSK Value 
#define CSID_S_REMOTE_AP_VAP5_WPAPSK               	    _STA_REMOTE(0x5e80)	//T=str, D="1234567890", AP VAP5 WPA PSK Value 
#define CSID_S_REMOTE_AP_VAP6_WPAPSK               	    _STA_REMOTE(0x5f00)	//T=str, D="1234567890", AP VAP6 WPA PSK Value 
#define CSID_S_REMOTE_AP_VAP7_WPAPSK               	    _STA_REMOTE(0x5f80)	//T=str, D="1234567890", AP VAP7 WPA PSK Value 
#define CSID_S_REMOTE_AP_VAP8_WPAPSK               	    _STA_REMOTE(0x6000)	//T=str, D="1234567890", AP VAP8 WPA PSK Value 
//Radius Server IP
#define CSID_S_REMOTE_AP_VAP1_RADIUS_SRVIP         	    _STA_REMOTE(0x6080)	//T=ipv4, VAP1 Radius Server IP 
#define CSID_S_REMOTE_AP_VAP2_RADIUS_SRVIP         	    _STA_REMOTE(0x6100)	//T=ipv4, VAP2 Radius Server IP 
#define CSID_S_REMOTE_AP_VAP3_RADIUS_SRVIP         	    _STA_REMOTE(0x6180)	//T=ipv4, VAP3 Radius Server IP 
#define CSID_S_REMOTE_AP_VAP4_RADIUS_SRVIP         	    _STA_REMOTE(0x6200)	//T=ipv4, VAP4 Radius Server IP 
#define CSID_S_REMOTE_AP_VAP5_RADIUS_SRVIP         	    _STA_REMOTE(0x6280)	//T=ipv4, VAP5 Radius Server IP 
#define CSID_S_REMOTE_AP_VAP6_RADIUS_SRVIP         	    _STA_REMOTE(0x6300)	//T=ipv4, VAP6 Radius Server IP 
#define CSID_S_REMOTE_AP_VAP7_RADIUS_SRVIP         	    _STA_REMOTE(0x6380)	//T=ipv4, VAP7 Radius Server IP 
#define CSID_S_REMOTE_AP_VAP8_RADIUS_SRVIP         	    _STA_REMOTE(0x6400)	//T=ipv4, VAP8 Radius Server IP 
//Radius Port
#define CSID_S_REMOTE_AP_VAP1_RADIUS_SRVPORT       	    _STA_REMOTE(0x6480)	//T=u16, D=1812, VAP1 Radius Server Port
#define CSID_S_REMOTE_AP_VAP2_RADIUS_SRVPORT       	    _STA_REMOTE(0x6500)	//T=u16, D=1812, VAP2 Radius Server Port
#define CSID_S_REMOTE_AP_VAP3_RADIUS_SRVPORT       	    _STA_REMOTE(0x6580)	//T=u16, D=1812, VAP3 Radius Server Port
#define CSID_S_REMOTE_AP_VAP4_RADIUS_SRVPORT       	    _STA_REMOTE(0x6600)	//T=u16, D=1812, VAP4 Radius Server Port
#define CSID_S_REMOTE_AP_VAP5_RADIUS_SRVPORT       	    _STA_REMOTE(0x6680)	//T=u16, D=1812, VAP5 Radius Server Port
#define CSID_S_REMOTE_AP_VAP6_RADIUS_SRVPORT       	    _STA_REMOTE(0x6700)	//T=u16, D=1812, VAP6 Radius Server Port
#define CSID_S_REMOTE_AP_VAP7_RADIUS_SRVPORT       	    _STA_REMOTE(0x6780)	//T=u16, D=1812, VAP7 Radius Server Port
#define CSID_S_REMOTE_AP_VAP8_RADIUS_SRVPORT       	    _STA_REMOTE(0x6800)	//T=u16, D=1812, VAP8 Radius Server Port
//Radius Share Key
#define CSID_S_REMOTE_AP_VAP1_RADIUS_SRVKEY        	    _STA_REMOTE(0x6880)	//T=str, VAP1 Radius Server Share Key 
#define CSID_S_REMOTE_AP_VAP2_RADIUS_SRVKEY        	    _STA_REMOTE(0x6900)	//T=str, VAP2 Radius Server Share Key
#define CSID_S_REMOTE_AP_VAP3_RADIUS_SRVKEY        	    _STA_REMOTE(0x6980)	//T=str, VAP3 Radius Server Share Key
#define CSID_S_REMOTE_AP_VAP4_RADIUS_SRVKEY        	    _STA_REMOTE(0x6a00)	//T=str, VAP4 Radius Server Share Key
#define CSID_S_REMOTE_AP_VAP5_RADIUS_SRVKEY        	    _STA_REMOTE(0x6a80)	//T=str, VAP5 Radius Server Share Key
#define CSID_S_REMOTE_AP_VAP6_RADIUS_SRVKEY        	    _STA_REMOTE(0x6b00)	//T=str, VAP6 Radius Server Share Key
#define CSID_S_REMOTE_AP_VAP7_RADIUS_SRVKEY        	    _STA_REMOTE(0x6b80)	//T=str, VAP7 Radius Server Share Key
#define CSID_S_REMOTE_AP_VAP8_RADIUS_SRVKEY        	    _STA_REMOTE(0x6c00)	//T=str, VAP8 Radius Server Share Key
//VLAN ID Enable
#define CSID_S_REMOTE_AP_VAP1_WIFI1_VLAN_ENABLE    	    _STA_REMOTE(0x6c80)	//T=u8, D=0, VAP1 WIFI1 VLAN ID enable
#define CSID_S_REMOTE_AP_VAP2_WIFI1_VLAN_ENABLE    	    _STA_REMOTE(0x6d00)	//T=u8, D=0, VAP2 WIFI1 VLAN ID enable
#define CSID_S_REMOTE_AP_VAP3_WIFI1_VLAN_ENABLE    	    _STA_REMOTE(0x6d80)	//T=u8, D=0, VAP3 WIFI1 VLAN ID enable
#define CSID_S_REMOTE_AP_VAP4_WIFI1_VLAN_ENABLE    	    _STA_REMOTE(0x6e00)	//T=u8, D=0, VAP4 WIFI1 VLAN ID enable
#define CSID_S_REMOTE_AP_VAP5_WIFI1_VLAN_ENABLE    	    _STA_REMOTE(0x6e80)	//T=u8, D=0, VAP5 WIFI1 VLAN ID enable
#define CSID_S_REMOTE_AP_VAP6_WIFI1_VLAN_ENABLE    	    _STA_REMOTE(0x6f00)	//T=u8, D=0, VAP6 WIFI1 VLAN ID enable
#define CSID_S_REMOTE_AP_VAP7_WIFI1_VLAN_ENABLE    	    _STA_REMOTE(0x6f80)	//T=u8, D=0, VAP7 WIFI1 VLAN ID enable
#define CSID_S_REMOTE_AP_VAP8_WIFI1_VLAN_ENABLE    	    _STA_REMOTE(0x7000)	//T=u8, D=0, VAP8 WIFI1 VLAN ID enable
//VLAN ID Value
#define CSID_S_REMOTE_AP_VAP1_WIFI1_VLAN_ID        	    _STA_REMOTE(0x7080)	//T=u32, D=3, VAP1 WIFI1_VLAN ID
#define CSID_S_REMOTE_AP_VAP2_WIFI1_VLAN_ID        	    _STA_REMOTE(0x7100)	//T=u32, D=3, VAP1 WIFI1_VLAN ID
#define CSID_S_REMOTE_AP_VAP3_WIFI1_VLAN_ID        	    _STA_REMOTE(0x7180)	//T=u32, D=3, VAP1 WIFI1_VLAN ID
#define CSID_S_REMOTE_AP_VAP4_WIFI1_VLAN_ID        	    _STA_REMOTE(0x7200)	//T=u32, D=3, VAP1 WIFI1_VLAN ID
#define CSID_S_REMOTE_AP_VAP5_WIFI1_VLAN_ID        	    _STA_REMOTE(0x7280)	//T=u32, D=3, VAP1 WIFI1_VLAN ID
#define CSID_S_REMOTE_AP_VAP6_WIFI1_VLAN_ID        	    _STA_REMOTE(0x7300)	//T=u32, D=3, VAP1 WIFI1_VLAN ID
#define CSID_S_REMOTE_AP_VAP7_WIFI1_VLAN_ID        	    _STA_REMOTE(0x7380)	//T=u32, D=3, VAP1 WIFI1_VLAN ID
#define CSID_S_REMOTE_AP_VAP8_WIFI1_VLAN_ID        	    _STA_REMOTE(0x7400)	//T=u32, D=3, VAP1 WIFI1_VLAN ID
//Max Supported Stations Enable
#define CSID_S_REMOTE_AP_VAP1_MAX_CLIENT_LIMIT     	    _STA_REMOTE(0x7480)	//T=u8, D=0, VAP1 Max Supported Stations, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP2_MAX_CLIENT_LIMIT     	    _STA_REMOTE(0x7500)	//T=u8, D=0, VAP2 Max Supported Stations, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP3_MAX_CLIENT_LIMIT     	    _STA_REMOTE(0x7580)	//T=u8, D=0, VAP3 Max Supported Stations, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP4_MAX_CLIENT_LIMIT     	    _STA_REMOTE(0x7600)	//T=u8, D=0, VAP4 Max Supported Stations, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP5_MAX_CLIENT_LIMIT     	    _STA_REMOTE(0x7680)	//T=u8, D=0, VAP5 Max Supported Stations, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP6_MAX_CLIENT_LIMIT     	    _STA_REMOTE(0x7700)	//T=u8, D=0, VAP6 Max Supported Stations, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP7_MAX_CLIENT_LIMIT     	    _STA_REMOTE(0x7780)	//T=u8, D=0, VAP7 Max Supported Stations, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP_VAP8_MAX_CLIENT_LIMIT     	    _STA_REMOTE(0x7800)	//T=u8, D=0, VAP8 Max Supported Stations, 0:Disable, 1:Enable
//Max Supported Stations value
#define CSID_S_REMOTE_AP_VAP1_MAX_CLIENT_NUM       	    _STA_REMOTE(0x7880)	//T=u8, VAP1 Max Supported Stations Value
#define CSID_S_REMOTE_AP_VAP2_MAX_CLIENT_NUM       	    _STA_REMOTE(0x7900)	//T=u8, VAP2 Max Supported Stations Value	
#define CSID_S_REMOTE_AP_VAP3_MAX_CLIENT_NUM       	    _STA_REMOTE(0x7980)	//T=u8, VAP3 Max Supported Stations Value
#define CSID_S_REMOTE_AP_VAP4_MAX_CLIENT_NUM       	    _STA_REMOTE(0x7a00)	//T=u8, VAP4 Max Supported Stations Value
#define CSID_S_REMOTE_AP_VAP5_MAX_CLIENT_NUM       	    _STA_REMOTE(0x7a80)	//T=u8, VAP5 Max Supported Stations Value
#define CSID_S_REMOTE_AP_VAP6_MAX_CLIENT_NUM       	    _STA_REMOTE(0x7b00)	//T=u8, VAP6 Max Supported Stations Value
#define CSID_S_REMOTE_AP_VAP7_MAX_CLIENT_NUM       	    _STA_REMOTE(0x7b80)	//T=u8, VAP7 Max Supported Stations Value
#define CSID_S_REMOTE_AP_VAP8_MAX_CLIENT_NUM       	    _STA_REMOTE(0x7c00)	//T=u8, VAP8 Max Supported Stations Value
//Bandwidth
#define CSID_S_REMOTE_AP_VAP1_HT_BW                	    _STA_REMOTE(0x7c80)	//T=u8, D=1, VAP1 BandWidth
#define CSID_S_REMOTE_AP_VAP2_HT_BW                	    _STA_REMOTE(0x7d00)	//T=u8, D=2, VAP2 BandWidth
#define CSID_S_REMOTE_AP_VAP3_HT_BW                	    _STA_REMOTE(0x7d80)	//T=u8, D=3, VAP3 BandWidth
#define CSID_S_REMOTE_AP_VAP4_HT_BW                	    _STA_REMOTE(0x7e00)	//T=u8, D=4, VAP4 BandWidth
#define CSID_S_REMOTE_AP_VAP5_HT_BW                	    _STA_REMOTE(0x7e80)	//T=u8, D=5, VAP5 BandWidth
#define CSID_S_REMOTE_AP_VAP6_HT_BW                	    _STA_REMOTE(0x7f00)	//T=u8, D=6, VAP6 BandWidth
#define CSID_S_REMOTE_AP_VAP7_HT_BW                	    _STA_REMOTE(0x7f80)	//T=u8, D=7, VAP7 BandWidth
#define CSID_S_REMOTE_AP_VAP8_HT_BW                	    _STA_REMOTE(0x8000)	//T=u8, D=8, VAP8 BandWidth
//RemoteAPMAC
#define CSID_S_REMOTE_AP_WDSAP1                		    _STA_REMOTE(0x8080)	//T=mac, AP WDS AP MAC Address1
#define CSID_S_REMOTE_AP_WDSAP2                		    _STA_REMOTE(0x8100)	//T=mac, AP WDS AP MAC Address2
#define CSID_S_REMOTE_AP_WDSAP3                  	    _STA_REMOTE(0x8180)	//T=mac, AP WDS AP MAC Address3
#define CSID_S_REMOTE_AP_WDSAP4                		    _STA_REMOTE(0x8200)	//T=mac, AP WDS AP MAC Address4

/*Wireless 2.4G Advanced Network Setting*/
#define CSID_S_REMOTE_AP_AREACODE					    _STA_REMOTE(0x8280)	//T=u8, AP 2.4G Area Code
#define CSID_S_REMOTE_AP_BEACONINTERVAL       		    _STA_REMOTE(0x8300)	//T=u16, D=100, AP Beacon Interval 
#define CSID_S_REMOTE_AP_TXPOWER                	    _STA_REMOTE(0x8380)	//T=u8, D=100, AP Tx Power Level 
#define CSID_S_REMOTE_AP_RTSCTSTHRESHOLD           	    _STA_REMOTE(0x8400)	//T=u16, D=2347, AP CTS/RTS Threshold
#define CSID_S_REMOTE_AP_FRAGTHRESHOLD             	    _STA_REMOTE(0x8480)	//T=u16, D=2346, AP Fragmentation Threshold 
#define CSID_S_REMOTE_AP_DTIMINTERVAL              	    _STA_REMOTE(0x8500)	//T=u16, D=1, DTIM interval
#define CSID_S_REMOTE_AP_WMMCAPABLE                	    _STA_REMOTE(0x8580)	//T=u32, D=1, AP WmmCapable  
#define CSID_S_REMOTE_AP_FIXED_DATARATE            	    _STA_REMOTE(0x8600)	//T=u8, AP Wlan Fixed Data Rate
#define CSID_S_REMOTE_AP_NOFORWARDINGBTNBSSID      	    _STA_REMOTE(0x8680)	//T=u8, AP Isolation, 0:Disable, 1:Enable


/* Wireless 5G */
#define CSID_S_REMOTE_AP2_WLANENABLE                    _STA_REMOTE(0x8700)  //T=u8, AP Wireless Main function, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_WIRELESS_MODE                 _STA_REMOTE(0x8780)  //T=u8, AP wireless mode
#define CSID_S_REMOTE_AP2_GREEN_AP                      _STA_REMOTE(0x8800)  //T=u8, AP Green AP, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_LAZY_MODE                     _STA_REMOTE(0x8880)  //T=u8, AP Lazy Mode, 0:Disable, 1:Enable
//SSID Enable
#define CSID_S_REMOTE_AP2_VAP1_APID_ENABLE              _STA_REMOTE(0x8900)  //T=u8, AP2 VAP1 SSID function, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP2_APID_ENABLE              _STA_REMOTE(0x8980)  //T=u8, AP2 VAP2 SSID function, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP3_APID_ENABLE              _STA_REMOTE(0x8a00)  //T=u8, AP2 VAP3 SSID function, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP4_APID_ENABLE              _STA_REMOTE(0x8a80)  //T=u8, AP2 VAP4 SSID function, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP5_APID_ENABLE              _STA_REMOTE(0x8b00)  //T=u8, AP2 VAP5 SSID function, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP6_APID_ENABLE              _STA_REMOTE(0x8b80)  //T=u8, AP2 VAP6 SSID function, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP7_APID_ENABLE              _STA_REMOTE(0x8c00)  //T=u8, AP2 VAP7 SSID function, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP8_APID_ENABLE              _STA_REMOTE(0x8c80)  //T=u8, AP2 VAP8 SSID function, 0:Disable, 1:Enable
//Schedule
#define CSID_S_REMOTE_AP2_VAP1_USE_RULE_NO              _STA_REMOTE(0x8d00)  //T=u16, AP2 VAP1 schedule number
#define CSID_S_REMOTE_AP2_VAP2_USE_RULE_NO              _STA_REMOTE(0x8d80)  //T=u16, AP2 VAP2 schedule number
#define CSID_S_REMOTE_AP2_VAP3_USE_RULE_NO              _STA_REMOTE(0x8e00)  //T=u16, AP2 VAP3 schedule number
#define CSID_S_REMOTE_AP2_VAP4_USE_RULE_NO              _STA_REMOTE(0x8e80)  //T=u16, AP2 VAP4 schedule number
#define CSID_S_REMOTE_AP2_VAP5_USE_RULE_NO              _STA_REMOTE(0x8f00)  //T=u16, AP2 VAP5 schedule number
#define CSID_S_REMOTE_AP2_VAP6_USE_RULE_NO              _STA_REMOTE(0x8f80)  //T=u16, AP2 VAP6 schedule number
#define CSID_S_REMOTE_AP2_VAP7_USE_RULE_NO              _STA_REMOTE(0x9000)  //T=u16, AP2 VAP7 schedule number
#define CSID_S_REMOTE_AP2_VAP8_USE_RULE_NO              _STA_REMOTE(0x9080)  //T=u16, AP2 VAP8 schedule number
//SSID  
#define CSID_S_REMOTE_AP2_VAP1_SSID             		_STA_REMOTE(0x9100)  //T=str, AP2 VAP1 SSID Name
#define CSID_S_REMOTE_AP2_VAP2_SSID             		_STA_REMOTE(0x9180)  //T=str, AP2 VAP2 SSID Name
#define CSID_S_REMOTE_AP2_VAP3_SSID             		_STA_REMOTE(0x9200)  //T=str, AP2 VAP3 SSID Name
#define CSID_S_REMOTE_AP2_VAP4_SSID             		_STA_REMOTE(0x9280)  //T=str, AP2 VAP4 SSID Name
#define CSID_S_REMOTE_AP2_VAP5_SSID             		_STA_REMOTE(0x9300)  //T=str, AP2 VAP5 SSID Name
#define CSID_S_REMOTE_AP2_VAP6_SSID            		 	_STA_REMOTE(0x9380)  //T=str, AP2 VAP6 SSID Name
#define CSID_S_REMOTE_AP2_VAP7_SSID             		_STA_REMOTE(0x9400)  //T=str, AP2 VAP7 SSID Name
#define CSID_S_REMOTE_AP2_VAP8_SSID             		_STA_REMOTE(0x9480)  //T=str, AP2 VAP8 SSID Name
//SSID Broadcast
#define CSID_S_REMOTE_AP2_VAP1_HIDESSID                 _STA_REMOTE(0x9500)  //T=u8, AP2 VAP1 SSID Broadcsat, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP2_HIDESSID                 _STA_REMOTE(0x9580)  //T=u8, AP2 VAP2 SSID Broadcsat, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP3_HIDESSID                 _STA_REMOTE(0x9600)  //T=u8, AP2 VAP3 SSID Broadcsat, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP4_HIDESSID                 _STA_REMOTE(0x9680)  //T=u8, AP2 VAP4 SSID Broadcsat, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP5_HIDESSID                 _STA_REMOTE(0x9700)  //T=u8, AP2 VAP5 SSID Broadcsat, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP6_HIDESSID                 _STA_REMOTE(0x9780)  //T=u8, AP2 VAP6 SSID Broadcsat, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP7_HIDESSID                 _STA_REMOTE(0x9800)  //T=u8, AP2 VAP7 SSID Broadcsat, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP8_HIDESSID                 _STA_REMOTE(0x9880)  //T=u8, AP2 VAP8 SSID Broadcsat, 0:Disable, 1:Enable
//WLAN Pratition
#define CSID_S_REMOTE_AP2_VAP1_NOFORWARDING             _STA_REMOTE(0x9900)	//T=u8, AP2 VAP1 WLAN Partitation, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP2_NOFORWARDING             _STA_REMOTE(0x9980)	//T=u8, AP2 VAP2 WLAN Partitation, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP3_NOFORWARDING             _STA_REMOTE(0x9a00)	//T=u8, AP2 VAP3 WLAN Partitation, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP4_NOFORWARDING             _STA_REMOTE(0x9a80)	//T=u8, AP2 VAP4 WLAN Partitation, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP5_NOFORWARDING             _STA_REMOTE(0x9b00)	//T=u8, AP2 VAP5 WLAN Partitation, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP6_NOFORWARDING             _STA_REMOTE(0x9b80)	//T=u8, AP2 VAP6 WLAN Partitation, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP7_NOFORWARDING             _STA_REMOTE(0x9c00)	//T=u8, AP2 VAP7 WLAN Partitation, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP8_NOFORWARDING             _STA_REMOTE(0x9c80)	//T=u8, AP2 VAP8 WLAN Partitation, 0:Disable, 1:Enable
//CHANNEL
#define CSID_S_REMOTE_AP2_VAP1_CHANNEL                  _STA_REMOTE(0x9d00)	//T=u8, AP2 VAP1 Channel
#define CSID_S_REMOTE_AP2_VAP2_CHANNEL                  _STA_REMOTE(0x9d80)	//T=u8, AP2 VAP2 Channel
#define CSID_S_REMOTE_AP2_VAP3_CHANNEL                  _STA_REMOTE(0x9e00)	//T=u8, AP2 VAP3 Channel
#define CSID_S_REMOTE_AP2_VAP4_CHANNEL                  _STA_REMOTE(0x9e80)	//T=u8, AP2 VAP4 Channel
#define CSID_S_REMOTE_AP2_VAP5_CHANNEL                  _STA_REMOTE(0x9f00)	//T=u8, AP2 VAP5 Channel
#define CSID_S_REMOTE_AP2_VAP6_CHANNEL                  _STA_REMOTE(0x9f80)	//T=u8, AP2 VAP6 Channel
#define CSID_S_REMOTE_AP2_VAP7_CHANNEL                  _STA_REMOTE(0xa000)	//T=u8, AP2 VAP7 Channel
#define CSID_S_REMOTE_AP2_VAP8_CHANNEL                  _STA_REMOTE(0xa080)	//T=u8, AP2 VAP8 Channel
//WirelessMode
#define CSID_S_REMOTE_AP2_VAP1_WIRLESSMODE              _STA_REMOTE(0xa100)	//T=u8, AP2 VAP1 Wireless Mode
#define CSID_S_REMOTE_AP2_VAP2_WIRLESSMODE              _STA_REMOTE(0xa180)	//T=u8, AP2 VAP2 Wireless Mode
#define CSID_S_REMOTE_AP2_VAP3_WIRLESSMODE              _STA_REMOTE(0xa200)	//T=u8, AP2 VAP3 Wireless Mode
#define CSID_S_REMOTE_AP2_VAP4_WIRLESSMODE              _STA_REMOTE(0xa280)	//T=u8, AP2 VAP4 Wireless Mode
#define CSID_S_REMOTE_AP2_VAP5_WIRLESSMODE              _STA_REMOTE(0xa300)	//T=u8, AP2 VAP5 Wireless Mode
#define CSID_S_REMOTE_AP2_VAP6_WIRLESSMODE              _STA_REMOTE(0xa380)	//T=u8, AP2 VAP6 Wireless Mode
#define CSID_S_REMOTE_AP2_VAP7_WIRLESSMODE              _STA_REMOTE(0xa400)	//T=u8, AP2 VAP7 Wireless Mode
#define CSID_S_REMOTE_AP2_VAP8_WIRLESSMODE              _STA_REMOTE(0xa480)	//T=u8, AP2 VAP8 Wireless Mode
//AuthMode
#define CSID_S_REMOTE_AP2_VAP1_AUTHMODE                 _STA_REMOTE(0xa500)	//T=u8, AP2 VAP1 Authenication Type
#define CSID_S_REMOTE_AP2_VAP2_AUTHMODE                 _STA_REMOTE(0xa580)	//T=u8, AP2 VAP2 Authenication Type
#define CSID_S_REMOTE_AP2_VAP3_AUTHMODE                 _STA_REMOTE(0xa600)	//T=u8, AP2 VAP3 Authenication Type
#define CSID_S_REMOTE_AP2_VAP4_AUTHMODE                 _STA_REMOTE(0xa680)	//T=u8, AP2 VAP4 Authenication Type
#define CSID_S_REMOTE_AP2_VAP5_AUTHMODE                 _STA_REMOTE(0xa700)	//T=u8, AP2 VAP5 Authenication Type
#define CSID_S_REMOTE_AP2_VAP6_AUTHMODE                 _STA_REMOTE(0xa780)	//T=u8, AP2 VAP6 Authenication Type
#define CSID_S_REMOTE_AP2_VAP7_AUTHMODE                 _STA_REMOTE(0xa800)	//T=u8, AP2 VAP7 Authenication Type
#define CSID_S_REMOTE_AP2_VAP8_AUTHMODE                 _STA_REMOTE(0xa880)	//T=u8, AP2 VAP8 Authenication Type
//IEEE 8021x       
#define CSID_S_REMOTE_AP2_VAP1_IEEE8021X                _STA_REMOTE(0xa900)	//T=u8, AP2 VAP1 8021X, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP2_IEEE8021X                _STA_REMOTE(0xa980)	//T=u8, AP2 VAP2 8021X, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP3_IEEE8021X                _STA_REMOTE(0xaa00)	//T=u8, AP2 VAP3 8021X, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP4_IEEE8021X                _STA_REMOTE(0xaa80)	//T=u8, AP2 VAP4 8021X, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP5_IEEE8021X                _STA_REMOTE(0xab00)	//T=u8, AP2 VAP5 8021X, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP6_IEEE8021X                _STA_REMOTE(0xab80)	//T=u8, AP2 VAP6 8021X, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP7_IEEE8021X                _STA_REMOTE(0xac00)	//T=u8, AP2 VAP7 8021X, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP8_IEEE8021X                _STA_REMOTE(0xac80)	//T=u8, AP2 VAP8 8021X, 0:Disable, 1:Enable
//Encryption
#define CSID_S_REMOTE_AP2_VAP1_ENCRYPTYPE               _STA_REMOTE(0xad00)	//T=u8, AP2 VAP1 Encryption Type
#define CSID_S_REMOTE_AP2_VAP2_ENCRYPTYPE               _STA_REMOTE(0xad80)	//T=u8, AP2 VAP2 Encryption Type
#define CSID_S_REMOTE_AP2_VAP3_ENCRYPTYPE               _STA_REMOTE(0xae00)	//T=u8, AP2 VAP3 Encryption Type
#define CSID_S_REMOTE_AP2_VAP4_ENCRYPTYPE               _STA_REMOTE(0xae80)	//T=u8, AP2 VAP4 Encryption Type
#define CSID_S_REMOTE_AP2_VAP5_ENCRYPTYPE               _STA_REMOTE(0xaf00)	//T=u8, AP2 VAP5 Encryption Type
#define CSID_S_REMOTE_AP2_VAP6_ENCRYPTYPE               _STA_REMOTE(0xaf80)	//T=u8, AP2 VAP6 Encryption Type
#define CSID_S_REMOTE_AP2_VAP7_ENCRYPTYPE               _STA_REMOTE(0xb000)	//T=u8, AP2 VAP7 Encryption Type
#define CSID_S_REMOTE_AP2_VAP8_ENCRYPTYPE               _STA_REMOTE(0xb080)	//T=u8, AP2 VAP8 Encryption Type
//WebKey Index        
#define CSID_S_REMOTE_AP2_VAP1_DEFKEYID                 _STA_REMOTE(0xb100)	//T=u8, D=1, AP2 VAP1 Default WEP Key ID
#define CSID_S_REMOTE_AP2_VAP2_DEFKEYID                 _STA_REMOTE(0xb180)	//T=u8, D=1, AP2 VAP2 Default WEP Key ID
#define CSID_S_REMOTE_AP2_VAP3_DEFKEYID                 _STA_REMOTE(0xb200)	//T=u8, D=1, AP2 VAP3 Default WEP Key ID
#define CSID_S_REMOTE_AP2_VAP4_DEFKEYID                 _STA_REMOTE(0xb280)	//T=u8, D=1, AP2 VAP4 Default WEP Key ID
#define CSID_S_REMOTE_AP2_VAP5_DEFKEYID                 _STA_REMOTE(0xb300)	//T=u8, D=1, AP2 VAP5 Default WEP Key ID
#define CSID_S_REMOTE_AP2_VAP6_DEFKEYID                 _STA_REMOTE(0xb380)	//T=u8, D=1, AP2 VAP6 Default WEP Key ID
#define CSID_S_REMOTE_AP2_VAP7_DEFKEYID                 _STA_REMOTE(0xb400)	//T=u8, D=1, AP2 VAP7 Default WEP Key ID
#define CSID_S_REMOTE_AP2_VAP8_DEFKEYID                 _STA_REMOTE(0xb480)	//T=u8, D=1, AP2 VAP8 Default WEP Key ID
//WebKey key1 Type
#define CSID_S_REMOTE_AP2_VAP1_KEY0TYPE                 _STA_REMOTE(0xb500)	//T=u8, D=0, AP2 VAP1 WEP Key0 Type
#define CSID_S_REMOTE_AP2_VAP2_KEY0TYPE                 _STA_REMOTE(0xb580)	//T=u8, D=0, AP2 VAP2 WEP Key0 Type
#define CSID_S_REMOTE_AP2_VAP3_KEY0TYPE                 _STA_REMOTE(0xb600)	//T=u8, D=0, AP2 VAP3 WEP Key0 Type
#define CSID_S_REMOTE_AP2_VAP4_KEY0TYPE                 _STA_REMOTE(0xb680)	//T=u8, D=0, AP2 VAP4 WEP Key0 Type
#define CSID_S_REMOTE_AP2_VAP5_KEY0TYPE                 _STA_REMOTE(0xb700)	//T=u8, D=0, AP2 VAP5 WEP Key0 Type
#define CSID_S_REMOTE_AP2_VAP6_KEY0TYPE                 _STA_REMOTE(0xb780)	//T=u8, D=0, AP2 VAP6 WEP Key0 Type
#define CSID_S_REMOTE_AP2_VAP7_KEY0TYPE                 _STA_REMOTE(0xb800)	//T=u8, D=0, AP2 VAP7 WEP Key0 Type
#define CSID_S_REMOTE_AP2_VAP8_KEY0TYPE                 _STA_REMOTE(0xb880)	//T=u8, D=0, AP2 VAP8 WEP Key0 Type
//Webkey 1
#define CSID_S_REMOTE_AP2_VAP1_KEY0                     _STA_REMOTE(0xb900)	//T=str, D="1234567890", AP2 VAP1 WEP Key0 Value
#define CSID_S_REMOTE_AP2_VAP2_KEY0                     _STA_REMOTE(0xb980)	//T=str, D="1234567890", AP2 VAP2 WEP Key0 Value
#define CSID_S_REMOTE_AP2_VAP3_KEY0                     _STA_REMOTE(0xba00)	//T=str, D="1234567890", AP2 VAP3 WEP Key0 Value
#define CSID_S_REMOTE_AP2_VAP4_KEY0                     _STA_REMOTE(0xba80)	//T=str, D="1234567890", AP2 VAP4 WEP Key0 Value
#define CSID_S_REMOTE_AP2_VAP5_KEY0                     _STA_REMOTE(0xbb00)	//T=str, D="1234567890", AP2 VAP5 WEP Key0 Value
#define CSID_S_REMOTE_AP2_VAP6_KEY0                     _STA_REMOTE(0xbb80)	//T=str, D="1234567890", AP2 VAP6 WEP Key0 Value
#define CSID_S_REMOTE_AP2_VAP7_KEY0                     _STA_REMOTE(0xbc00)	//T=str, D="1234567890", AP2 VAP7 WEP Key0 Value
#define CSID_S_REMOTE_AP2_VAP8_KEY0                     _STA_REMOTE(0xbc80)	//T=str, D="1234567890", AP2 VAP8 WEP Key0 Value
//WebKey key2 Type
#define CSID_S_REMOTE_AP2_VAP1_KEY1TYPE                 _STA_REMOTE(0xbd00)	//T=u8, D=0, AP2 VAP1 WEP Key1 Type
#define CSID_S_REMOTE_AP2_VAP2_KEY1TYPE                 _STA_REMOTE(0xbd80)	//T=u8, D=0, AP2 VAP2 WEP Key1 Type
#define CSID_S_REMOTE_AP2_VAP3_KEY1TYPE                 _STA_REMOTE(0xbe00)	//T=u8, D=0, AP2 VAP3 WEP Key1 Type
#define CSID_S_REMOTE_AP2_VAP4_KEY1TYPE                 _STA_REMOTE(0xbe80)	//T=u8, D=0, AP2 VAP4 WEP Key1 Type
#define CSID_S_REMOTE_AP2_VAP5_KEY1TYPE                 _STA_REMOTE(0xbf00)	//T=u8, D=0, AP2 VAP5 WEP Key1 Type
#define CSID_S_REMOTE_AP2_VAP6_KEY1TYPE                 _STA_REMOTE(0xbf80)	//T=u8, D=0, AP2 VAP6 WEP Key1 Type
#define CSID_S_REMOTE_AP2_VAP7_KEY1TYPE                 _STA_REMOTE(0xc000)	//T=u8, D=0, AP2 VAP7 WEP Key1 Type
#define CSID_S_REMOTE_AP2_VAP8_KEY1TYPE                 _STA_REMOTE(0xc080)	//T=u8, D=0, AP2 VAP8 WEP Key1 Type
//Webkey 2
#define CSID_S_REMOTE_AP2_VAP1_KEY1                     _STA_REMOTE(0xc100)	//T=str, D="1234567890", AP2 VAP1 WEP Key1 Value
#define CSID_S_REMOTE_AP2_VAP2_KEY1                     _STA_REMOTE(0xc180)	//T=str, D="1234567890", AP2 VAP2 WEP Key1 Value
#define CSID_S_REMOTE_AP2_VAP3_KEY1                     _STA_REMOTE(0xc200)	//T=str, D="1234567890", AP2 VAP3 WEP Key1 Value
#define CSID_S_REMOTE_AP2_VAP4_KEY1                     _STA_REMOTE(0xc280)	//T=str, D="1234567890", AP2 VAP4 WEP Key1 Value
#define CSID_S_REMOTE_AP2_VAP5_KEY1                     _STA_REMOTE(0xc300)	//T=str, D="1234567890", AP2 VAP5 WEP Key1 Value
#define CSID_S_REMOTE_AP2_VAP6_KEY1                     _STA_REMOTE(0xc380)	//T=str, D="1234567890", AP2 VAP6 WEP Key1 Value
#define CSID_S_REMOTE_AP2_VAP7_KEY1                     _STA_REMOTE(0xc400)	//T=str, D="1234567890", AP2 VAP7 WEP Key1 Value
#define CSID_S_REMOTE_AP2_VAP8_KEY1                     _STA_REMOTE(0xc480)	//T=str, D="1234567890", AP2 VAP8 WEP Key1 Value
//WebKey key3 Type
#define CSID_S_REMOTE_AP2_VAP1_KEY2TYPE                 _STA_REMOTE(0xc500)	//T=u8, D=0, AP2 VAP1 WEP Key2 Type
#define CSID_S_REMOTE_AP2_VAP2_KEY2TYPE                 _STA_REMOTE(0xc580)	//T=u8, D=0, AP2 VAP2 WEP Key2 Type
#define CSID_S_REMOTE_AP2_VAP3_KEY2TYPE                 _STA_REMOTE(0xc600)	//T=u8, D=0, AP2 VAP3 WEP Key2 Type
#define CSID_S_REMOTE_AP2_VAP4_KEY2TYPE                 _STA_REMOTE(0xc680)	//T=u8, D=0, AP2 VAP4 WEP Key2 Type
#define CSID_S_REMOTE_AP2_VAP5_KEY2TYPE                 _STA_REMOTE(0xc700)	//T=u8, D=0, AP2 VAP5 WEP Key2 Type
#define CSID_S_REMOTE_AP2_VAP6_KEY2TYPE                 _STA_REMOTE(0xc780)	//T=u8, D=0, AP2 VAP6 WEP Key2 Type
#define CSID_S_REMOTE_AP2_VAP7_KEY2TYPE                 _STA_REMOTE(0xc800)	//T=u8, D=0, AP2 VAP7 WEP Key2 Type
#define CSID_S_REMOTE_AP2_VAP8_KEY2TYPE                 _STA_REMOTE(0xc880)	//T=u8, D=0, AP2 VAP8 WEP Key2 Type
//Webkey 3
#define CSID_S_REMOTE_AP2_VAP1_KEY2                     _STA_REMOTE(0xc900)	//T=str, D="1234567890", AP2 VAP1 WEP Key2 Value
#define CSID_S_REMOTE_AP2_VAP2_KEY2                     _STA_REMOTE(0xc980)	//T=str, D="1234567890", AP2 VAP2 WEP Key2 Value
#define CSID_S_REMOTE_AP2_VAP3_KEY2                     _STA_REMOTE(0xca00)	//T=str, D="1234567890", AP2 VAP3 WEP Key2 Value
#define CSID_S_REMOTE_AP2_VAP4_KEY2                     _STA_REMOTE(0xca80)	//T=str, D="1234567890", AP2 VAP4 WEP Key2 Value
#define CSID_S_REMOTE_AP2_VAP5_KEY2                     _STA_REMOTE(0xcb00)	//T=str, D="1234567890", AP2 VAP5 WEP Key2 Value
#define CSID_S_REMOTE_AP2_VAP6_KEY2                     _STA_REMOTE(0xcb80)	//T=str, D="1234567890", AP2 VAP6 WEP Key2 Value
#define CSID_S_REMOTE_AP2_VAP7_KEY2                     _STA_REMOTE(0xcc00)	//T=str, D="1234567890", AP2 VAP7 WEP Key2 Value
#define CSID_S_REMOTE_AP2_VAP8_KEY2                     _STA_REMOTE(0xcc80)	//T=str, D="1234567890", AP2 VAP8 WEP Key2 Value
//WebKey key4 Type
#define CSID_S_REMOTE_AP2_VAP1_KEY3TYPE                 _STA_REMOTE(0xcd00)	//T=u8, D=0, AP2 VAP1 WEP Key3 Type
#define CSID_S_REMOTE_AP2_VAP2_KEY3TYPE                 _STA_REMOTE(0xcd80)	//T=u8, D=0, AP2 VAP2 WEP Key3 Type
#define CSID_S_REMOTE_AP2_VAP3_KEY3TYPE                 _STA_REMOTE(0xce00)	//T=u8, D=0, AP2 VAP3 WEP Key3 Type	
#define CSID_S_REMOTE_AP2_VAP4_KEY3TYPE                 _STA_REMOTE(0xce80)	//T=u8, D=0, AP2 VAP4 WEP Key3 Type
#define CSID_S_REMOTE_AP2_VAP5_KEY3TYPE                 _STA_REMOTE(0xcf00)	//T=u8, D=0, AP2 VAP5 WEP Key3 Type
#define CSID_S_REMOTE_AP2_VAP6_KEY3TYPE                 _STA_REMOTE(0xcf80)	//T=u8, D=0, AP2 VAP6 WEP Key3 Type
#define CSID_S_REMOTE_AP2_VAP7_KEY3TYPE                 _STA_REMOTE(0xd000)	//T=u8, D=0, AP2 VAP7 WEP Key3 Type
#define CSID_S_REMOTE_AP2_VAP8_KEY3TYPE                 _STA_REMOTE(0xd080)	//T=u8, D=0, AP2 VAP8 WEP Key3 Type
//Webkey 4
#define CSID_S_REMOTE_AP2_VAP1_KEY3                     _STA_REMOTE(0xd100)	//T=str, D="1234567890", AP2 VAP1 WEP Key3 Value
#define CSID_S_REMOTE_AP2_VAP2_KEY3                     _STA_REMOTE(0xd180)	//T=str, D="1234567890", AP2 VAP2 WEP Key3 Value
#define CSID_S_REMOTE_AP2_VAP3_KEY3                     _STA_REMOTE(0xd200)	//T=str, D="1234567890", AP2 VAP3 WEP Key3 Value
#define CSID_S_REMOTE_AP2_VAP4_KEY3                     _STA_REMOTE(0xd280)	//T=str, D="1234567890", AP2 VAP4 WEP Key3 Value
#define CSID_S_REMOTE_AP2_VAP5_KEY3                     _STA_REMOTE(0xd300)	//T=str, D="1234567890", AP2 VAP5 WEP Key3 Value
#define CSID_S_REMOTE_AP2_VAP6_KEY3                     _STA_REMOTE(0xd380)	//T=str, D="1234567890", AP2 VAP6 WEP Key3 Value
#define CSID_S_REMOTE_AP2_VAP7_KEY3                     _STA_REMOTE(0xd400)	//T=str, D="1234567890", AP2 VAP7 WEP Key3 Value
#define CSID_S_REMOTE_AP2_VAP8_KEY3                     _STA_REMOTE(0xd480)	//T=str, D="1234567890", AP2 VAP8 WEP Key3 Value
//Preshare Key
#define CSID_S_REMOTE_AP2_VAP1_WPAPSK                   _STA_REMOTE(0xd500)	//T=str, D="1234567890", AP2 VAP1 WPA PSK Value 
#define CSID_S_REMOTE_AP2_VAP2_WPAPSK                   _STA_REMOTE(0xd580)	//T=str, D="1234567890", AP2 VAP2 WPA PSK Value 
#define CSID_S_REMOTE_AP2_VAP3_WPAPSK                   _STA_REMOTE(0xd600)	//T=str, D="1234567890", AP2 VAP3 WPA PSK Value 
#define CSID_S_REMOTE_AP2_VAP4_WPAPSK                   _STA_REMOTE(0xd680)	//T=str, D="1234567890", AP2 VAP4 WPA PSK Value 
#define CSID_S_REMOTE_AP2_VAP5_WPAPSK                   _STA_REMOTE(0xd700)	//T=str, D="1234567890", AP2 VAP5 WPA PSK Value 
#define CSID_S_REMOTE_AP2_VAP6_WPAPSK                   _STA_REMOTE(0xd780)	//T=str, D="1234567890", AP2 VAP6 WPA PSK Value 
#define CSID_S_REMOTE_AP2_VAP7_WPAPSK                   _STA_REMOTE(0xd800)	//T=str, D="1234567890", AP2 VAP7 WPA PSK Value 
#define CSID_S_REMOTE_AP2_VAP8_WPAPSK                   _STA_REMOTE(0xd880)	//T=str, D="1234567890", AP2 VAP8 WPA PSK Value 
//Radius Server IP
#define CSID_S_REMOTE_AP2_VAP1_RADIUS_SRVIP             _STA_REMOTE(0xd900)	//T=ipv4, AP2 VAP1 Radius Server IP 
#define CSID_S_REMOTE_AP2_VAP2_RADIUS_SRVIP             _STA_REMOTE(0xd980)	//T=ipv4, AP2 VAP2 Radius Server IP 
#define CSID_S_REMOTE_AP2_VAP3_RADIUS_SRVIP             _STA_REMOTE(0xda00)	//T=ipv4, AP2 VAP3 Radius Server IP 
#define CSID_S_REMOTE_AP2_VAP4_RADIUS_SRVIP             _STA_REMOTE(0xda80)	//T=ipv4, AP2 VAP4 Radius Server IP 
#define CSID_S_REMOTE_AP2_VAP5_RADIUS_SRVIP             _STA_REMOTE(0xdb00)	//T=ipv4, AP2 VAP5 Radius Server IP 
#define CSID_S_REMOTE_AP2_VAP6_RADIUS_SRVIP             _STA_REMOTE(0xdb80)	//T=ipv4, AP2 VAP6 Radius Server IP 
#define CSID_S_REMOTE_AP2_VAP7_RADIUS_SRVIP             _STA_REMOTE(0xdc00)	//T=ipv4, AP2 VAP7 Radius Server IP 
#define CSID_S_REMOTE_AP2_VAP8_RADIUS_SRVIP             _STA_REMOTE(0xdc80)	//T=ipv4, AP2 VAP8 Radius Server IP 
//Radius Port
#define CSID_S_REMOTE_AP2_VAP1_RADIUS_SRVPORT           _STA_REMOTE(0xdd00)	//T=u16, D=1812, AP2 VAP1 Radius Server Port
#define CSID_S_REMOTE_AP2_VAP2_RADIUS_SRVPORT           _STA_REMOTE(0xdd80)	//T=u16, D=1812, AP2 VAP2 Radius Server Port
#define CSID_S_REMOTE_AP2_VAP3_RADIUS_SRVPORT           _STA_REMOTE(0xde00)	//T=u16, D=1812, AP2 VAP3 Radius Server Port
#define CSID_S_REMOTE_AP2_VAP4_RADIUS_SRVPORT           _STA_REMOTE(0xde80)	//T=u16, D=1812, AP2 VAP4 Radius Server Port
#define CSID_S_REMOTE_AP2_VAP5_RADIUS_SRVPORT           _STA_REMOTE(0xdf00)	//T=u16, D=1812, AP2 VAP5 Radius Server Port
#define CSID_S_REMOTE_AP2_VAP6_RADIUS_SRVPORT           _STA_REMOTE(0xdf80)	//T=u16, D=1812, AP2 VAP6 Radius Server Port
#define CSID_S_REMOTE_AP2_VAP7_RADIUS_SRVPORT           _STA_REMOTE(0xe000)	//T=u16, D=1812, AP2 VAP7 Radius Server Port
#define CSID_S_REMOTE_AP2_VAP8_RADIUS_SRVPORT           _STA_REMOTE(0xe080)	//T=u16, D=1812, AP2 VAP8 Radius Server Port
//Radius Share Key
#define CSID_S_REMOTE_AP2_VAP1_RADIUS_SRVKEY            _STA_REMOTE(0xe100)	//T=str, AP2 VAP1 Radius Server Share Key 
#define CSID_S_REMOTE_AP2_VAP2_RADIUS_SRVKEY            _STA_REMOTE(0xe180)	//T=str, AP2 VAP2 Radius Server Share Key
#define CSID_S_REMOTE_AP2_VAP3_RADIUS_SRVKEY            _STA_REMOTE(0xe200)	//T=str, AP2 VAP3 Radius Server Share Key
#define CSID_S_REMOTE_AP2_VAP4_RADIUS_SRVKEY            _STA_REMOTE(0xe280)	//T=str, AP2 VAP4 Radius Server Share Key
#define CSID_S_REMOTE_AP2_VAP5_RADIUS_SRVKEY            _STA_REMOTE(0xe300)	//T=str, AP2 VAP5 Radius Server Share Key
#define CSID_S_REMOTE_AP2_VAP6_RADIUS_SRVKEY            _STA_REMOTE(0xe380)	//T=str, AP2 VAP6 Radius Server Share Key
#define CSID_S_REMOTE_AP2_VAP7_RADIUS_SRVKEY            _STA_REMOTE(0xe400)	//T=str, AP2 VAP7 Radius Server Share Key
#define CSID_S_REMOTE_AP2_VAP8_RADIUS_SRVKEY            _STA_REMOTE(0xe480)	//T=str, AP2 VAP8 Radius Server Share Key
//VLAN ID Enable
#define CSID_S_REMOTE_AP2_VAP1_WIFI1_VLAN_ENABLE        _STA_REMOTE(0xe500)	//T=u8, D=0, AP2 VAP1 WIFI1 VLAN ID enable
#define CSID_S_REMOTE_AP2_VAP2_WIFI1_VLAN_ENABLE        _STA_REMOTE(0xe580)	//T=u8, D=0, AP2 VAP2 WIFI1 VLAN ID enable
#define CSID_S_REMOTE_AP2_VAP3_WIFI1_VLAN_ENABLE        _STA_REMOTE(0xe600)	//T=u8, D=0, AP2 VAP3 WIFI1 VLAN ID enable
#define CSID_S_REMOTE_AP2_VAP4_WIFI1_VLAN_ENABLE        _STA_REMOTE(0xe680)	//T=u8, D=0, AP2 AP2 VAP4 WIFI1 VLAN ID enable
#define CSID_S_REMOTE_AP2_VAP5_WIFI1_VLAN_ENABLE        _STA_REMOTE(0xe700)	//T=u8, D=0, AP2 VAP5 WIFI1 VLAN ID enable
#define CSID_S_REMOTE_AP2_VAP6_WIFI1_VLAN_ENABLE        _STA_REMOTE(0xe780)	//T=u8, D=0, AP2 VAP6 WIFI1 VLAN ID enable
#define CSID_S_REMOTE_AP2_VAP7_WIFI1_VLAN_ENABLE        _STA_REMOTE(0xe800)	//T=u8, D=0, AP2 VAP7 WIFI1 VLAN ID enable
#define CSID_S_REMOTE_AP2_VAP8_WIFI1_VLAN_ENABLE        _STA_REMOTE(0xe880)	//T=u8, D=0, AP2 VAP8 WIFI1 VLAN ID enable
//VLAN ID Value
#define CSID_S_REMOTE_AP2_VAP1_WIFI1_VLAN_ID            _STA_REMOTE(0xe900)	//T=u32, D=3, AP2 VAP1 WIFI1_VLAN ID
#define CSID_S_REMOTE_AP2_VAP2_WIFI1_VLAN_ID            _STA_REMOTE(0xe980)	//T=u32, D=3, AP2 VAP1 WIFI1_VLAN ID
#define CSID_S_REMOTE_AP2_VAP3_WIFI1_VLAN_ID            _STA_REMOTE(0xea00)	//T=u32, D=3, AP2 VAP1 WIFI1_VLAN ID
#define CSID_S_REMOTE_AP2_VAP4_WIFI1_VLAN_ID            _STA_REMOTE(0xea80)	//T=u32, D=3, AP2 VAP1 WIFI1_VLAN ID
#define CSID_S_REMOTE_AP2_VAP5_WIFI1_VLAN_ID            _STA_REMOTE(0xeb00)	//T=u32, D=3, AP2 VAP1 WIFI1_VLAN ID
#define CSID_S_REMOTE_AP2_VAP6_WIFI1_VLAN_ID            _STA_REMOTE(0xeb80)	//T=u32, D=3, AP2 VAP1 WIFI1_VLAN ID
#define CSID_S_REMOTE_AP2_VAP7_WIFI1_VLAN_ID            _STA_REMOTE(0xec00)	//T=u32, D=3, AP2 VAP1 WIFI1_VLAN ID
#define CSID_S_REMOTE_AP2_VAP8_WIFI1_VLAN_ID            _STA_REMOTE(0xec80)	//T=u32, D=3, AP2 VAP1 WIFI1_VLAN ID
//Max Supported Stations Enable
#define CSID_S_REMOTE_AP2_VAP1_MAX_CLIENT_LIMIT         _STA_REMOTE(0xed00)	//T=u8, D=0, AP2 VAP1 Max Supported Stations, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP2_MAX_CLIENT_LIMIT         _STA_REMOTE(0xed80)	//T=u8, D=0, AP2 VAP2 Max Supported Stations, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP3_MAX_CLIENT_LIMIT         _STA_REMOTE(0xee00)	//T=u8, D=0, AP2 VAP3 Max Supported Stations, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP4_MAX_CLIENT_LIMIT         _STA_REMOTE(0xee80)	//T=u8, D=0, AP2 VAP4 Max Supported Stations, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP5_MAX_CLIENT_LIMIT         _STA_REMOTE(0xef00)	//T=u8, D=0, AP2 VAP5 Max Supported Stations, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP6_MAX_CLIENT_LIMIT         _STA_REMOTE(0xef80)	//T=u8, D=0, AP2 VAP6 Max Supported Stations, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP7_MAX_CLIENT_LIMIT         _STA_REMOTE(0xf000)	//T=u8, D=0, AP2 VAP7 Max Supported Stations, 0:Disable, 1:Enable
#define CSID_S_REMOTE_AP2_VAP8_MAX_CLIENT_LIMIT         _STA_REMOTE(0xf080)	//T=u8, D=0, AP2 VAP8 Max Supported Stations, 0:Disable, 1:Enable
//Max Supported Stations value
#define CSID_S_REMOTE_AP2_VAP1_MAX_CLIENT_NUM           _STA_REMOTE(0xf100)	//T=u8, AP2 VAP1 Max Supported Stations Value
#define CSID_S_REMOTE_AP2_VAP2_MAX_CLIENT_NUM           _STA_REMOTE(0xf180)	//T=u8, AP2 VAP2 Max Supported Stations Value	
#define CSID_S_REMOTE_AP2_VAP3_MAX_CLIENT_NUM           _STA_REMOTE(0xf200)	//T=u8, AP2 VAP3 Max Supported Stations Value
#define CSID_S_REMOTE_AP2_VAP4_MAX_CLIENT_NUM           _STA_REMOTE(0xf280)	//T=u8, AP2 VAP4 Max Supported Stations Value
#define CSID_S_REMOTE_AP2_VAP5_MAX_CLIENT_NUM           _STA_REMOTE(0xf300)	//T=u8, AP2 VAP5 Max Supported Stations Value
#define CSID_S_REMOTE_AP2_VAP6_MAX_CLIENT_NUM           _STA_REMOTE(0xf380)	//T=u8, AP2 VAP6 Max Supported Stations Value
#define CSID_S_REMOTE_AP2_VAP7_MAX_CLIENT_NUM           _STA_REMOTE(0xf400)	//T=u8, AP2 VAP7 Max Supported Stations Value
#define CSID_S_REMOTE_AP2_VAP8_MAX_CLIENT_NUM           _STA_REMOTE(0xf480)	//T=u8, AP2 VAP8 Max Supported Stations Value
//Bandwidth
#define CSID_S_REMOTE_AP2_VAP1_HT_BW                    _STA_REMOTE(0xf500)	//T=u8, D=1, AP2 VAP1 BandWidth
#define CSID_S_REMOTE_AP2_VAP2_HT_BW                    _STA_REMOTE(0xf580)	//T=u8, D=2, AP2 VAP2 BandWidth
#define CSID_S_REMOTE_AP2_VAP3_HT_BW                    _STA_REMOTE(0xf600)	//T=u8, D=3, AP2 VAP3 BandWidth
#define CSID_S_REMOTE_AP2_VAP4_HT_BW                    _STA_REMOTE(0xf680)	//T=u8, D=4, AP2 VAP4 BandWidth
#define CSID_S_REMOTE_AP2_VAP5_HT_BW                    _STA_REMOTE(0xf700)	//T=u8, D=5, AP2 VAP5 BandWidth
#define CSID_S_REMOTE_AP2_VAP6_HT_BW                    _STA_REMOTE(0xf780)	//T=u8, D=6, AP2 VAP6 BandWidth
#define CSID_S_REMOTE_AP2_VAP7_HT_BW                    _STA_REMOTE(0xf800)	//T=u8, D=7, AP2 VAP7 BandWidth
#define CSID_S_REMOTE_AP2_VAP8_HT_BW                    _STA_REMOTE(0xf880)	//T=u8, D=8, AP2 VAP8 BandWidth
//RemoteAPMAC
#define CSID_S_REMOTE_AP2_WDSAP1                	    _STA_REMOTE(0xf900)	//T=mac, AP2 AP2 WDS AP MAC Address1
#define CSID_S_REMOTE_AP2_WDSAP2                	    _STA_REMOTE(0xf980)	//T=mac, AP2 AP2 WDS AP MAC Address2
#define CSID_S_REMOTE_AP2_WDSAP3                  	    _STA_REMOTE(0xfa00)	//T=mac, AP2 AP2 WDS AP MAC Address3
#define CSID_S_REMOTE_AP2_WDSAP4                	    _STA_REMOTE(0xfa80)	//T=mac, AP2 AP2 WDS AP MAC Address4
/*Wireless 5G Advanced Network Setting*/
#define CSID_S_REMOTE_AP2_AREACODE					    _STA_REMOTE(0xfb00)	//T=u8, AP2 5G Area Code
#define CSID_S_REMOTE_AP2_BEACONINTERVAL       		    _STA_REMOTE(0xfb80)	//T=u16, D=100, AP2 Beacon Interval 
#define CSID_S_REMOTE_AP2_TXPOWER                	    _STA_REMOTE(0xfc00)	//T=u8, D=100, AP2 Tx Power Level 
#define CSID_S_REMOTE_AP2_RTSCTSTHRESHOLD               _STA_REMOTE(0xfc80)	//T=u16, D=2347, AP2 CTS/RTS Threshold
#define CSID_S_REMOTE_AP2_FRAGTHRESHOLD                 _STA_REMOTE(0xfd00)	//T=u16, D=2346, AP2 Fragmentation Threshold 
#define CSID_S_REMOTE_AP2_DTIMINTERVAL                  _STA_REMOTE(0xfd80)	//T=u16, D=1, AP2 DTIM interval
#define CSID_S_REMOTE_AP2_WMMCAPABLE                    _STA_REMOTE(0xfe00)	//T=u32, D=1, AP2 WmmCapable  
#define CSID_S_REMOTE_AP2_FIXED_DATARATE                _STA_REMOTE(0xfe80)	//T=u8, AP2 Wlan Fixed Data Rate
#define CSID_S_REMOTE_AP2_NOFORWARDINGBTNBSSID          _STA_REMOTE(0xff00)	//T=u8, AP2 Isolation, 0:Disable, 1:Enable

//#define CSID_C_X509_EN                            _CFG_X509(0x0000) //T=u32, X509 Enable
//#define CSID_C_X509_CERT_EN                       _CFG_X509(0x0100) //T=u32, D=0,X509 certificate Enable,0:default


#endif //ifndef _CSID_REMOTE_H


