/*
 * @file Member ID Definition of Group REMOTE_SEC.
 *
 * Moderator: Aaron Wu
 * Group ID: 0x00770000/0x80770000
 */

#ifndef _CSID_REMOTE_SEC_H
#define _CSID_REMOTE_SEC_H

#include "csid_gid.h"

#define _CFG_REMOTE_SEC(x)       (CSID_GIDC_REMOTE_SEC|(x))
#define _STA_REMOTE_SEC(x)       (CSID_GIDS_REMOTE_SEC|(x))

/* Extra Definitions */

/* SNMP Setting Items */
//Basic	
#define CSID_S_REMOTE_SEC_AP_SNMP_GET_COMMUNITY                   _STA_REMOTE_SEC(0x0000)  //T=str, AP SNMP Get Community
#define CSID_S_REMOTE_SEC_AP_SNMP_SET_COMMUNITY                   _STA_REMOTE_SEC(0x0080)  //T=str, AP SNMP Set Community
#define CSID_S_REMOTE_SEC_AP_SNMP_VERSION_V1                      _STA_REMOTE_SEC(0x0100)  //T=u16, AP SNMP V1 Enable
#define CSID_S_REMOTE_SEC_AP_SNMP_VERSION_V2C                     _STA_REMOTE_SEC(0x0180)  //T=u16, AP SNMP V2C Enable
#define CSID_S_REMOTE_SEC_AP_SNMP_VERSION_V3                      _STA_REMOTE_SEC(0x0200)  //T=u16, AP SNMP V3 Enable
//SNMP V3
#define CSID_S_REMOTE_SEC_AP_SNMP_V3_USER_ENABLE                  _STA_REMOTE_SEC(0x0280)  //T=u16, AP SNMP v3 Enable Multi Account, 1:yes,0:no  
#define CSID_S_REMOTE_SEC_AP_SNMP_V3_USER                         _STA_REMOTE_SEC(0x0300)  //T=str, AP SNMP v3 User Account
#define CSID_S_REMOTE_SEC_AP_SNMP_V3_PASSWORD                     _STA_REMOTE_SEC(0x0380)  //T=str, AP SNMP v3 User Password
#define CSID_S_REMOTE_SEC_AP_SNMP_V3_AUTHTYPE                     _STA_REMOTE_SEC(0x0400)  //T=u16, AP SNMP v3 Auth Type, 0:MD5,1:SHA 
#define CSID_S_REMOTE_SEC_AP_SNMP_V3_PRIVACYMODE                  _STA_REMOTE_SEC(0x0480)  //T=u16, AP SNMP v3 Privacy Mode, 0:noAuthNoPriv,1:authNoPriv,2:authPriv
#define CSID_S_REMOTE_SEC_AP_SNMP_V3_PRIVACY                      _STA_REMOTE_SEC(0x0500)  //T=str, AP SNMP v3 DES passphrase 
#define CSID_S_REMOTE_SEC_AP_SNMP_V3_RO_RW                        _STA_REMOTE_SEC(0x0580)  //T=str, AP SNMP v3 User RO/RW Enable, 0:read only,1:read write                               

/*Wireless Mode Need other parameters to set*/
#define CSID_S_REMOTE_SEC_AP_BASICRATE                            _STA_REMOTE_SEC(0x0600)	//T=u8, D=15, 2.4G basic rate                   
#define CSID_S_REMOTE_SEC_AP_FIXEDTXMODE                          _STA_REMOTE_SEC(0x0680)	//T=str, D='HT'  
#define CSID_S_REMOTE_SEC_AP2_BASICRATE                           _STA_REMOTE_SEC(0x0700)	//T=u8, D=15, 2.4G basic rate 
#define CSID_S_REMOTE_SEC_AP2_FIXEDTXMODE                         _STA_REMOTE_SEC(0x0780)	//T=str, D='HT'
#define CSID_S_REMOTE_SEC_AP_GI                         		  _STA_REMOTE_SEC(0x0800)	//T=u8, 2.4G Short GI 0: Disable, 1:Enable
#define CSID_S_REMOTE_SEC_AP2_GI                         		  _STA_REMOTE_SEC(0x0880)	//T=u8, 5G Short GI 0: Disable, 1:Enable
#define CSID_S_REMOTE_SEC_WLANAPCLI_MAC                           _STA_REMOTE_SEC(0x0900)	//T=str, 2.4G AP MAC for Universal Repeater Mode
#define CSID_S_REMOTE_SEC_WLANAP2CLI_MAC                          _STA_REMOTE_SEC(0x0980)	//T=str, 5G AP MAC for Universal Repeater Mode


/* LAN & VLAN */
/* The Item is using AP mode CSID*/	
#define CSID_S_REMOTE_SEC_AP_CNT_TYPE							  _STA_REMOTE_SEC(0x0a00)  //T=u32, AP Mode Connect Type, 0: DHCP, 1:Static
#define CSID_S_REMOTE_SEC_AP_FIX_IF_GW							  _STA_REMOTE_SEC(0x0a80)  //T=ipv4, AP Mode Static Gateway
#define CSID_S_REMOTE_SEC_AP_FIX_IF_PRIDNS						  _STA_REMOTE_SEC(0x0b00)  //T=ipv4, AP Mode Static Primary DNS
#define CSID_S_REMOTE_SEC_AP_FIX_IF_SECDNS						  _STA_REMOTE_SEC(0x0b80)  //T=ipv4, AP Mode Static Secondary DNS
#define CSID_S_REMOTE_SEC_AP_FIX_IF_IP							  _STA_REMOTE_SEC(0x0c00)  //T=ipv4, AP Mode Static IP Address
#define CSID_S_REMOTE_SEC_AP_FIX_IF_NM							  _STA_REMOTE_SEC(0x0c80)  //T=ipv4, AP Mode Static Subnet Mask

//Trust AP Items, reserved 128 items	
#define CSID_S_REMOTE_SEC_AP_TRUSTAP_PARSED                   	  _STA_REMOTE_SEC(0x0d00)  //T=u8, indicate if this AP's WiFi setting is parsed


#endif //ifndef _CSID_REMOTE_SEC_H


