/*
 * @file Member ID Definition of Group SSLVPN.
 *
 * Moderator: Austin
 * Group ID: 0x009C0000/0x809C0000
 */

#ifndef _CSID_SSLVPN_H
#define _CSID_SSLVPN_H

#include "csid_gid.h"

#define _CFG_SSLVPN(x)       (CSID_GIDC_SSLVPN|(x))
#define _STA_SSLVPN(x)       (CSID_GIDS_SSLVPN|(x))

/* Extra Definitions */
//X.509

#define CSID_S_SSLVPN_ALTERED						_STA_SSLVPN(0x0000) //T=u32, ui altered of SSL VPN
#define CSID_S_SSLVPN_CMD                        	_STA_SSLVPN(0x0001) //T=u32, cmd of SSLVPN
#define CSID_S_SSLVPN_ACTIDX                        _STA_SSLVPN(0x0002) //T=u32, idx of SSLVPN 
#define CSID_S_SSLVPN_OS_DETECTION                  _STA_SSLVPN(0x0003) //T=u32, os of SSLVPN 
#define CSID_S_SSLVPN_BROWSER_DETECTION             _STA_SSLVPN(0x0004) //T=u32, browser of SSLVPN 

#define CSID_C_SSLVPN_EN                            _CFG_SSLVPN(0x0000) //T=u32, D=0,SSLVPN Enable
#define CSID_C_SSLVPN_MULTI_WAN_ENABLE              _CFG_SSLVPN(0x0001) //T=u32, SSLVPN Enable

#define CSID_C_SSLVPN_SVR_IP                        _CFG_SSLVPN(0x0010) //T=ipv4, SSLVPN Enable
#define CSID_C_SSLVPN_SVR_PORT                      _CFG_SSLVPN(0x0020) //T=u32, D=443,SSLVPN Enable
#define CSID_C_SSLVPN_SVR_PROTO                     _CFG_SSLVPN(0x0030) //T=u32, D=0,0:udp,1:tcp
#define CSID_C_SSLVPN_SVR_DEV                       _CFG_SSLVPN(0x0040) //T=u32, D=0,0:tun,1:tap

#define CSID_C_SSLVPN_IDLE_TIMEOUT                  _CFG_SSLVPN(0x0050) //T=u32, D=3600, idle timeout
#define CSID_C_SSLVPN_CLEAN_WEB_CACHE_ENABLE        _CFG_SSLVPN(0x0060) //T=u32, D=0, Clean web cache enable

#define CSID_C_SSLVPN_SVR_PUSH_DNS_EN               _CFG_SSLVPN(0x0070) //T=u32, D=0, SSLVPN DNS
#define CSID_C_SSLVPN_SVR_PRIDNS                    _CFG_SSLVPN(0x0080) //T=ipv4, SSLVPN Primary DNS
#define CSID_C_SSLVPN_SVR_SECDNS                    _CFG_SSLVPN(0x0090) //T=ipv4, SSLVPN Second DNS

#define CSID_C_SSLVPN_SVR_PUSH_WINS_EN              _CFG_SSLVPN(0x00A0) //T=u32, D=0,SSLVPN WINS
#define CSID_C_SSLVPN_SVR_PRIWINS                   _CFG_SSLVPN(0x00B0) //T=ipv4, Primary WINS 
#define CSID_C_SSLVPN_SVR_SECWINS                   _CFG_SSLVPN(0x00C0) //T=ipv4, Second WINS  

#define CSID_C_SSLVPN_SVR_PUSH_LAN                  _CFG_SSLVPN(0x00D0) //T=u32, D=0,SSLVPN Push LAN to Client

#define CSID_C_SSLVPN_VIRTUAL_IP					_CFG_SSLVPN(0x00E0) //T=ipv4, D={10.8.0.0}, SSLVPN Client IP
#define CSID_C_SSLVPN_VIRTUAL_IP_SUBNET				_CFG_SSLVPN(0x00F0) //T=ipv4, D={255.255.255.0}, SSLVPN Client Subnet

#define CSID_C_SSLVPN_FULL_TUNNEL_ENABLE        	_CFG_SSLVPN(0x0100) //T=u32, D=0, SSLVPN full tunnel enable
#define CSID_C_SSLVPN_SVR_MAXLEASE                  _CFG_SSLVPN(0x0110) //T=u32, D=5,SSLVPN IPPool Max Lease tap only
#define CSID_C_SSLVPN_SVR_IPPOOL_START              _CFG_SSLVPN(0x0120) //T=ipv4, D={192.168.10.200},SSLVPN start lan ip tap only
#define CSID_C_SSLVPN_SVR_IPPOOL_END                _CFG_SSLVPN(0x0130) //T=ipv4, D={192.168.10.210},SSLVPN end lan ip tap only

#define CSID_C_SSLVPN_SVR_MAX_CLIENT                _CFG_SSLVPN(0x0140) //T=u32, D=2,SSLVPN Max Clients

#define CSID_C_SSLVPN_SVR_MAX_KEEP_ALIVE            _CFG_SSLVPN(0x0150) //T=u32, D=60,SSLVPN maximum keep alive 
#define CSID_C_SSLVPN_SVR_MIN_KEEP_ALIVE            _CFG_SSLVPN(0x0160) //T=u32, D=20,SSLVPN minimum keep alive 

#define CSID_C_SSLVPN_AUTH                          _CFG_SSLVPN(0x0170) //T=u32, D=0,SSLVPN authentication 0:default
#define CSID_C_SSLVPN_CIPHER                        _CFG_SSLVPN(0x0180) //T=u32, D=0,SSLVPN cipher 0:default
#define CSID_C_SSLVPN_COMP                          _CFG_SSLVPN(0x0190) //T=u32, D=0,SSLVPN compression 0:default
#define CSID_C_SSLVPN_REDIRECT_GW_EN                _CFG_SSLVPN(0x01A0) //T=u32, D=0,SSLVPN Redirection gateway
#define CSID_C_SSLVPN_LOGIN_STRING            		_CFG_SSLVPN(0x01B0) //T=str, login string
#define CSID_C_SSLVPN_LOGIN_LOGO            		_CFG_SSLVPN(0x01C0) //T=u32, login logo

#define CSID_C_SSLVPN_APPLICATION_ALL_EN	        _CFG_SSLVPN(0x0200) //T=u32, D=0,SSLVPN Application all enable
#define CSID_C_SSLVPN_APPLICATION_EN		        _CFG_SSLVPN(0x0300) //T=u32, D=0,SSLVPN Application enable
#define CSID_C_SSLVPN_APPLICATION_TYPE		        _CFG_SSLVPN(0x0400) //T=u32, D=0,SSLVPN Application type
#define CSID_C_SSLVPN_APPLICATION_IP       			_CFG_SSLVPN(0x0500) //T=ipv4, Application IP
#define CSID_C_SSLVPN_APPLICATION_PORT              _CFG_SSLVPN(0x0600) //T=u32, Application Port
#define CSID_C_SSLVPN_RDP_SCREEN_SIZE       		_CFG_SSLVPN(0x0700) //T=u32, D=0,RDP Screen size
#define CSID_C_SSLVPN_VNC_SCALING              		_CFG_SSLVPN(0x0800) //T=u32, D=0,VPN port Scaling

#define CSID_C_SSLVPN_USR_ENABLE                  	_CFG_SSLVPN(0x0900) //T=str, SSLVPN user enable
#define CSID_C_SSLVPN_USERNAME                  	_CFG_SSLVPN(0x0A00) //T=str, SSLVPN account username
#define CSID_C_SSLVPN_PASSWORD                  	_CFG_SSLVPN(0x0B00) //T=str, SSLVPN account password
#define CSID_C_SSLVPN_USR_LEVEL                 	_CFG_SSLVPN(0x0C00) //T=u32, D=0, SSLVPN account user level
#define CSID_C_SSLVPN_USR_GROUP_ENABLE              _CFG_SSLVPN(0x0D00) //T=u32, SSLVPN group enable
#define CSID_C_SSLVPN_USR_GROUP_NAME            	_CFG_SSLVPN(0x0E00) //T=str, D=0, SSLVPN group name
#define CSID_C_SSLVPN_USR_GROUP_LEVEL            	_CFG_SSLVPN(0x0F00) //T=str, D=0, SSLVPN group name
#define CSID_C_SSLVPN_USR_CONNECT_STATUS           	_CFG_SSLVPN(0x1A00) //T=u32, D=0, SSLVPN user connect status
#define CSID_C_SSLVPN_USR_CONNECT_IP	           	_CFG_SSLVPN(0x1B00) //T=ipv4, SSLVPN user connect ip

#endif //ifndef _CSID_X509_H


