/*
 * @file Member ID Definition of Group X509.
 *
 * Moderator: Austin
 * Group ID: 0x00750000/0x80750000
 */

#ifndef _CSID_X509_H
#define _CSID_X509_H

#include "csid_gid.h"

#define _CFG_X509(x)       (CSID_GIDC_X509|(x))
#define _STA_X509(x)       (CSID_GIDS_X509|(x))

/* Extra Definitions */
//X.509

#define CSID_S_X509_ALTERED						  _STA_X509(0x0000) //T=u32, ui altered of X509
#define CSID_S_X509_ACTIDX                        _STA_X509(0x0001) //T=u32, idx of X509 certificate

#define CSID_C_X509_EN                            _CFG_X509(0x0000) //T=u32, D=0,X509 Enable
#define CSID_C_X509_CA_SERIAL                     _CFG_X509(0x0001) //T=str, X509 root CA serial
#define CSID_C_X509_CERT_EN                       _CFG_X509(0x0100) //T=u32, D=0,X509 certificate Enable,0:default

#define CSID_C_X509_NAME                          _CFG_X509(0x0200) //T=str, X509 certificate name
#define CSID_C_X509_SELF_SIGN_EN                  _CFG_X509(0x0300) //T=u32, D=0,Self sign,0:default
#define CSID_C_X509_PRIVATE_KEY    	              _CFG_X509(0x0400) //T=str, X509 CA private key
#define CSID_C_X509_CERT                          _CFG_X509(0x0500) //T=str, X509 certificate, 0:root CA, 1~16:Local Certificates, 17~32:Trusted CA Certificates, 33~48:Trusted Client Certificates
#define CSID_C_X509_CERT_2                        _CFG_X509(0x0600) //T=str, X509 certificate 2
#define CSID_C_X509_ISSUER                        _CFG_X509(0x0700) //T=str, X509 certificate issuer
#define CSID_C_X509_VALID_TO                      _CFG_X509(0x0800) //T=str, X509 certificate valid to
#define CSID_C_X509_SUBJECT                       _CFG_X509(0x0900) //T=str, X509 certificate subject

#define CSID_C_X509_VALID_DAYS                    _CFG_X509(0x0A00) //T=u32, D=3650,X509 certificate valid days
#define CSID_C_X509_KEY_SIZE                      _CFG_X509(0x0B00) //T=u32, D=512,X509 certificate key size
#define CSID_C_X509_SUBJECT_COUNTRY               _CFG_X509(0x0C00) //T=str, X509 certificate subject country
#define CSID_C_X509_SUBJECT_STATE                 _CFG_X509(0x0D00) //T=str, X509 certificate subject state
#define CSID_C_X509_SUBJECT_LOCATION              _CFG_X509(0x0E00) //T=str, X509 certificate subject location
#define CSID_C_X509_SUBJECT_ORGANIZATION          _CFG_X509(0x0F00) //T=str, X509 certificate subject organization
#define CSID_C_X509_SUBJECT_ORGANIZATION_UNIT     _CFG_X509(0x1000) //T=str, X509 certificate subject organization
#define CSID_C_X509_SUBJECT_COMMON_NAME           _CFG_X509(0x1100) //T=str, X509 certificate subject common name
#define CSID_C_X509_SUBJECT_EMAIL                 _CFG_X509(0x1200) //T=str, X509 certificate subject email

#define CSID_C_X509_IPSEC_CERT_EN                 _CFG_X509(0x2000) //T=u32, D=0,X509 certificate Enable,0:default
#define CSID_C_X509_IPSEC_L_CERT                  _CFG_X509(0x2100) //T=str, X509 certificate name for local ipsec.conf
#define CSID_C_X509_IPSEC_R_CERT                  _CFG_X509(0x2200) //T=str, X509 certificate name for remote ipsec.conf

#endif //ifndef _CSID_X509_H


